PROC GLOBAL

{------- Se eliminan zspct zseval zscoef ---------- funciones Antropometricas ---}
{ --------------------------------------------------------------------------- }

set explicit;
{ Working variables }
array wenter(50); { Working var recording entry of individuals }
alpha(26) alphavar;
alpha(26) alphanew;

numeric zscoeff zsr zsb1 zsb2 zsb3 zsb4 zsb5 zsdz zst
  zsdzp zsfx zsll zsul zsa zsknot zsi zsj zsk zsl
  zsz zsc zsy1 zsy2 zsy3 zssd1 zssd2 zshta
  zspmed zsv zshac zshap zshaz zswap zswaz zswac zshtw 
  zswhp zswhz zswhc fhaz fwaz fwhz zsflag leapday x
  xdays1 y xdays2 vcheckx addmode qmark lx l totlen
  aok alphsize a maxmem maxovc hhnum minage maxage minab
  chhlth chlabl chlabu mindi cln err i dd ss
  di lev grd numovc j xline xwomen xchild
  ddw diwm udob ldob t ldobfc udobfc ldoblc udoblc
  dich hwsex hwage hwerr birthd birthm
  birthy age xweight xheight
  ldofm udofm minam;

numeric esquema;
{ --------------------------------------------------------------------------- }
{ valid
  Checks that a variable has a valid value.
  A valid value is less than 96 and not a special value e.g notappl/missing
  Returns: 1 if valid, 0 if not valid                                        }

function valid(xvar);
  valid = (!special(xvar) and xvar < 96)
end;

{ -------------------------------------------------------------------------- }
{ NAtoZero
  Converts notappl values to zero while not changing other values.
  Returns: 0 if input variable is notappl, else returns it unchanged         }
function NAtoZero(xvar);
  if xvar = notappl then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

{ -------------------------------------------------------------------------- }
{ Anthropometry function zscoef        }
{ Height and Weight Z-score functions }
{ ----------  Eliminada!! -------------  }


{ --------------------------------------------------------------------------- }
{ dabs
  Returns: the absolute value of input variable                               }

function dabs(dval);
  if dval < 0 then dval = - dval endif;
  dabs = dval;
end;

{ --------------------------------------------------------------------------- }
{ Anthropometry function zspct  }
{  --------  Eliminada  -----------  }

{ --------------------------------------------------------------------------- }
{ Anthropometry function zseval  }
{  --------  Eliminada  -----------  }

{ --------------------------------------------------------------------------- }
{ Anthropometry function zscr  }
{  --------  Eliminada  -----------  }

{ --------------------------------------------------------------------------- }
{ Anthropometry function zsanth  }
{  --------  Eliminada  -----------  }

{ --------------------------------------------------------------------------- }
{ agemth
  Calculates most accurate age in months possible (used for anthropometry)
  Input: Birth day, month, year and interview day, month, year
  Returns:
        - Childs age in months if birth day, month and year are valid
        - Childs age in months using 15 as day if only birth month and year are valid
        - special if only birth year is valid                                        }

  function agemth(xhwbd,xhwbm,xhwby,xhwmd,xhwmm,xhwmy);
    { if birth month and year and measurement day, month and year are all valid }
    if valid(xhwbd) and valid(xhwbm) and valid(xhwmd) and valid(xhwmm) and xhwmy < 9996 then
      { if day of birth inconsistent, don't know or missing }
      if not(valid(xhwbd)) then
        { impute day of birth }
        xhwbd = 15;
      endif;
      leapday = (xhwby % 4 = 0);
      x = 1;
      xdays1 = xhwbd;
      while x < xhwbm do
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays1 = xdays1 + y;
        x = x + 1
      enddo;
      leapday = (xhwmy % 4 = 0);
      x = 1;
      xdays2 = xhwmd;
      while x < xhwmm do
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays2 = xdays2 + y;
        x = x + 1
      enddo;
      x = xhwby;
      while x < xhwmy do
        xdays2 = xdays2 + 365 + (x % 4 = 0);
        x = x + 1
      enddo;
      agemth = int(((xdays2 - xdays1)/30.4375)*100+0.5)/100;
    else
      agemth = 9999;
    endif;
  end;

{ --------------------------------------------------------------------------- }
{ vdvalid
  Checks that date is valid. Used for checking vaccination dates.
  Missing, dont know etc are considered valid
  Returns: 1 if valid, otherwise 0                                                                                        }

function vdvalid(vcheckd,vcheckm,vchecky);
  vdvalid = 0;
  { Check day, month and year are consistent }
  recode    vchecky   : vcheckm               : vcheckd    => vcheckx; { !!! }
  2004-2006,9996-9999 : 1,3,5,7,8,10,12,96-99 : 1-31,96-99 => 0;
  2004-2006,9996-9999 : 4,6,9,11              : 1-30,96-99 => 0;
  2004-2006,9996-9999 : 2                     : 1-28,96-99 => 0;
  2004,2004           : 2                     : 29         => 0;       { leap year }
              notappl : notappl               : 66         => 0;
              notappl : notappl               : 44         => 0;
              notappl : notappl               : 0          => 0;
                      :                       :            => 1;
  endrecode;
  if vcheckx then
    vdvalid = 1;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ vdoi
  Check vaccination date is before date of interview.
  Returns: 0 if vaccination date is before interview, otherwise 1 }
function vdoi(vcheckd,vcheckm,vchecky);
  vdoi = 0;
  if (vcheckd < 44 and vcheckd > 0) and valid(vcheckm) and vchecky < 9996 then
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) |
        (cmcode(vcheckm,vchecky) = cmcode(UF8M,UF8Y) and vcheckd > UF8D) then
      vdoi = 1;
    endif;
  elseif valid(vcheckm) and vchecky < 9996 then
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) then
      vdoi = 1;
    endif;
  elseif vchecky < 9996 then
    if vchecky > UF8Y then
      vdoi = 1;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ vdob
  Check vaccination date is after date of birth
  Returns: 0 if vaccination date is after birth, otherwise 1  }
function vdob(vcheckd,vcheckm,vchecky);
  vdob = 0;
  if valid(UF10D) and valid(UF10M) and UF10Y < 9996 then
    if vcheckd < 44 and valid(vcheckm) and vchecky < 9996 then
      if cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) | (cmcode(vcheckm,vchecky) = cmcode(UF10M,UF10Y) and vcheckd < UF10D) then
        vdob = 1;
      endif;
    elseif valid(vcheckm) and vchecky < 9996 and cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) then
      vdob = 1;
    elseif vchecky < 9996 and vchecky < UF10Y then
      vdob = 1;
    endif;
  elseif valid(UF10M) and UF10Y < 9996 then
    if valid(vcheckm) and vchecky < 9996 and cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) then
      vdob = 1;
    elseif vchecky < 9996 and vchecky < UF10Y then
      vdob = 1;
    endif;
  elseif UF10Y < 9996 then
    if vchecky < 9996 and vchecky < UF10Y then
      vdob = 1;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }
{ endmess
  If user is in addmode, it displays a menu with the options
  "Review Questionnaire" and "Next Questionnaire"
  Returns: 1 if user is in addmode or selects Next Questionnaire, 0 otherwise }

function endmess();
  { Returns true if response is REVIEW }
  endmess = (addmode and
             accept("Fin del Cuestionario",
                    "Revisar Cuestionario",
                    "Proximo Cuestionario") <> 2);
end;

{ --------------------------------------------------------------------------- }
{ russian_convert
  Converts a letter from the cyrillic alphabet to the latin alphabet.
  The convert map is found in separate file                                                                       }

function russian_convert();
  do l = 1 while l <= length(strip(alphavar))
    x = pos(alphavar[l:1],"");
    if x then
      alphavar[l:1] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"[x:1];
    endif;
  enddo;
end;

{ --------------------------------------------------------------------------- }
{ Function to check entry of alpha string variables }
{ alphachk
  Function to check entry of alpha string variables.
  Requirement: preceed with the statment alphavar = $
  Input variables:
  alphamask - The characters allowed and the order and position of these
  alphavar (set before calling the function) - the variable to be checked

  Checks that all the characters in the alphavar variable is found in alphamask
  and that they are in correct order. Repositions the characters before returning.
  If ? is found in string, makes sure that no other characters are present
  Returns: Repositioned string if valid, else 0

  Examples:
  alphavar    alphamask     returns
  "ABC"           "ABCDEX"      "ABC   "
  "AC"            "ABCDEX"      "A C   "
  "BEX"           "ABCDEX"      " B  EX"
  "?"             "ABCDEX"      "??????"
  "J"             "ABCDEX"      0
  "ABQ"           "ABCDEX"      0
  "?A"            "ABCDEX"      0
  "BA"            "ABCDEX"      0 (wrong order)                 }

function alphachk(alpha(26) alphamask);
{  russian_convert();}
  { first remove all blanks, and duplicate question marks }
  alphanew = "";
  qmark = 0;
  lx = 1;
  do l = 1 while l <= length(strip(alphavar))
    if alphavar[l:1] <> " " and (alphavar[l:1] <> "?" or not qmark) then
      alphanew[lx:1] = alphavar[l:1];
      lx = lx + 1;
      if alphavar[l:1] = "?" then
        qmark = 1;
      endif;
    endif;
  enddo;
  { aok = 0 - string is bad, aok = 1 - string is good }
  totlen = length(strip(alphamask));
  aok = 0;           { assume string is bad - for empty string }
  alphsize = length(strip(alphanew));
  if alphsize then   { not empty string }
    { check for "?" as only character }
    aok = (alphanew[1:1] = "?" and alphsize = 1);
    if !aok then     { if not a single "?", check string }
      aok = 1;       { now assume string is good until we know otherwise }
      l = 1;         { l is position in string of acceptable values }
      a = 1;         { a is position in input string }
      { loop while the string is still good and there are more letters }
      while aok and a <= alphsize do
        aok = pos(alphanew[a:1],alphamask[l:totlen-l+1]);
        if aok then     { letter is acceptable }
          l = l + aok;  { increment l to position after letter in string of acceptable values }
          a = a + 1     { increment a to next letter in input string }
        endif;
      enddo;
    endif;
  endif;
  alphachk = (!aok);    { alphachk = 0 - if string is good, = 1 - if string is bad }
  { now expand variables }
  if aok then
    do l = 1 while l <= length(strip(alphamask))
      if pos(alphamask[l:1],alphanew) then
        alphavar[l:1] = alphamask[l:1]
      elseif pos("?",alphanew) then
        alphavar[l:1] = "?"
      else
        alphavar[l:1] = " "
      endif;
    enddo;
  endif;
end;





PROC FL_ENTRY
preproc
maxmem = 50;      { maximum number of household members }
maxovc = 50;      { maximum number of OVCs }
hhnum  = 0;       { last household number used }
minage = 15;      { minimum age of eligible women }
maxage = 49;      { maximum age of eligible women }
minab  = 144;     { minimum age at birth in months = 12 years }
minam  = 48;      { minimum age at first marriage = 4 years }
chhlth = 1;       { maximum age at which child is included in child health module - excludes exact age 5 }
chlabl = 5;       { minimum age at which child is included in child labor module - includes exact age 5 }
chlabu = 14;      { maximum age at which child is included in child labor module - excludes exact age 15 }
mindi = 20060101; { OJO -> replace "20050401" with earliest interview date in yyyymmdd format }
addmode = (demode() = ADD);
cln=tonumber(sysparm());
recode cln  => err;
     001-501 => 0;    { Our Maximum valid cluster numbers for Cuba }
    { 001-032 => 0;    { Give list of valid cluster Pinar }}
	{ 033-064 => 0;    { Give list of valid cluster P Habana }}
    { 065-163 => 0;    { Give list of valid cluster C. Hab }}
    { 164-193 => 0;    { Give list of valid cluster Mat }}
    { 194-230 => 0;    { Give list of valid cluster V. Clara }}
    { 231-248 => 0;    { Give list of valid cluster Cienf }}
    { 249-269 => 0;    { Give list of valid cluster Sancti Spritus }}
    { 270-287 => 0;    { Give list of valid cluster Ciego de Avila }}
    { 288-322 => 0;    { Give list of valid cluster Camagey }}
    { 323-345 => 0;    { Give list of valid cluster Las Tunas }}
    { 346-391 => 0;    { Give list of valid cluster Holgun }}
    { 392-428 => 0;    { Give list of valid cluster Granma }}
    { 429-474 => 0;    { Give list of valid cluster Santiago de Cuba }}
    { 475-497 => 0;    { Give list of valid cluster Guantnamo }}
    { 498-501 => 0;    { Give list of valid cluster Isla de la Juventud }}
            => 1;
endrecode;
if err then
  errmsg(0010);
  endlevel;
endif;

PROC HH
{ *** Level 1 *** }
preproc
  { Initialization prior to the entry of a household questionnaire }

  { Initialize the working woman's line number
    and the flags for the entry of eligible women }
  i = 1;
  while i <= maxmem do
    wenter(i) = 0;
    i = i + 1;
  enddo;

PROC FORMHH
if HH9 <> 1 then
  if endmess() then
    reenter HH16
  endif;
  endlevel
endif;

PROC HH1
if HH1 <> cln then
  errmsg(0010);
  reenter
endif;

PROC HH2
if addmode and HH2 < hhnum then
  errmsg(0012);
endif;
hhnum = HH2;

PROC HH5Y
recode HH5Y  :     HH5M        : HH5D => err;
   		2006 : 1,3,5,7         : 1-31 => 0;
   		2006 : 4,6             : 1-30 => 0;
   		2006 : 2               : 1-28 => 0;
     	     :                 :      => 1;
endrecode;
if err then
  errmsg(0016);
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ss = sysdate("yyyymmdd");
if dd >= ss or dd < mindi then
  errmsg(0016);
  reenter
endif;
di = cmcode(HH5M,HH5Y);

PROC HH6
recode HH1  : HH6 => err;   {We have to modify this for cuban's areas!! }
    001-019 :  1  => 0;
    020-031 :  2  => 0;
    032-032 : 1,2 => 0;
    033-055 :  1  => 0;
    056-063 :  2  => 0;
    064-064 : 1,2 => 0;
    065-184 :  1  => 0;
    185-189 :  2  => 0;
    190-193 : 1,2 => 0;
    194-202 :  1  => 0;
    203-203 :  2  => 0;
    204-205 :  1  => 0;
    206-206 :  2  => 0;
    207-219 :  1  => 0;
    220-224 :  2  => 0;
    225-226 :  1  => 0;
    227-230 :  2  => 0;
    231-244 :  1  => 0;
    245-249 :  2  => 0;
    250-250 :  1  => 0;
    251-251 :  2  => 0;
    252-252 :  1  => 0;
    253-253 :  2  => 0;
    254-255 :  1  => 0;
    256-256 :  2  => 0;
    257-258 :  1  => 0;
    259-259 :  2  => 0;
    260-260 :  1  => 0;
    261-261 :  2  => 0;
    262-263 :  1  => 0;
    264-264 : 1,2 => 0;
    265-268 :  1  => 0;
    269-269 :  2  => 0;
    270-282 :  1  => 0;
    283-287 :  2  => 0;
    288-313 :  1  => 0;
    314-322 :  2  => 0;
    323-336 :  1  => 0;
    337-345 :  2  => 0;
    346-372 :  1  => 0;
    373-391 :  2  => 0;
    392-411 :  1  => 0;
    412-427 :  2  => 0;
    428-428 : 1,2 => 0;
    429-459 :  1  => 0;
    460-476 :  2  => 0;
    477-486 :  1  => 0;
    487-487 :  2  => 0;
    488-488 :  1  => 0;
    489-489 :  2  => 0;
    490-490 :  1  => 0;
    491-492 :  2  => 0;
    493-493 :  1  => 0;
    494-495 :  2  => 0;
    496-496 :  1  => 0;
    497-497 :  2  => 0;
    498-500 :  1  => 0;
    501-501 :  2  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011);
  reenter
endif;

PROC HH7
recode HH1  : HH7 => err;
    001-064 :  1  => 0;
    065-163 :  2  => 0;
    164-193 :  1  => 0;
    194-322 :  3  => 0;
    323-497 :  4  => 0;
    498-501 :  1  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011);
  reenter
endif;

PROC HH9
if HH9 <> 1 then
  skip to HH16
endif;

PROC HH12
if HH12 > HH11 then
  errmsg(0015);
  reenter
endif;

PROC HH13
if HH13 > HH12 then
  errmsg(0014);
  reenter
endif;

PROC HH14
if HH12+HH14 > HH11 then
  errmsg(0015);
  reenter
endif;

PROC HH15
if HH15 > HH14 then
  errmsg(0013);
  reenter
endif;

PROC FORMHL


PROC HL1
preproc
if noccurs(FORMHL_ROSTER) >= HH11 then
  endgroup
endif;

i = 1;
while i <= maxmem do
  if i <= HH11 then
    HL1(i) = i
  else
    HL1(i) = notappl
  endif;
  i = i + 1
enddo;
PROC HL6
preproc
if not (HL4 = 2 and HL5 in minage:maxage) then
  HL6 = 0;
  noinput;
endif;

postproc
if HL4 = 2 and HL5 in minage:maxage then
  if HL6 <> HL1 then
    errmsg(0101);
    reenter
  endif;
else
  if HL6 <> 0 then
    errmsg(0102);
    reenter
  endif;
endif;

PROC HL8
preproc
if HL5 > chhlth then
  HL8 = 0;
  noinput;
endif;

postproc
if HL5 <= chhlth then
  if HL8 = 0 or HL8 = HL1 then
    errmsg(0131);
    reenter
  elseif HL8 > HH11 then
    errmsg(0130,HL8,HH11);
    reenter
  endif;
else
  if HL8 <> 0 then
    errmsg(0132);
    reenter
  endif;
endif;

PROC ED2
preproc
if HL5(HL1) < 5 then
  skip to next HL1
endif;

postproc
if ED2 <> 1 then
  skip to next HL1
endif;

PROC ED3B
lev = ED3A;
grd = ED3B;
recode lev  : grd         => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          0 : 0-0         => 0;   { preescolar}
          1 : 0-6         => 0;   { Primaria }
          2 : 0-3         => 0;   { Secundaria }
          3 : 0-5         => 0;   { Obrero }
          4 : 0-5 		  => 0;   { PreUniv/Tc }
          5 : 0-7 		  => 0;   { Superior}
          8 :             => 0;   { no sabe }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(0090);
  { reenter }
endif;

PROC TOHL6 {NEW}
if TOHL6 <> count(FORMHL_ROSTER where HL6 > 0) then
  errmsg(0110,"Mujeres 15-49");
  reenter;
elseif TOHL6 <> HH12 then
  errmsg(0111,"Mujeres 15-49",TOHL6,"HH12",HH12);
  reenter;
endif;

PROC TOHL8 {NEW}
if TOHL8 <> count(FORMHL_ROSTER where HL8 > 0) then
  errmsg(0110,"Menores de 2");
  reenter;
elseif TOHL8 <> HH14 then
  errmsg(0111,"Menores de 2",TOHL8,"HH14",HH14);
  reenter;
endif;

PROC WS1
if WS1 in 11, 12 then
  skip to WS5
elseif WS1 in 13:81,96,99 then
  skip to WS3
{ elseif WS1 = 91 then { bottled water }
  skip to WS2 }
endif;

PROC WS2
if WS2 in 11, 12 then
  skip to WS5
endif;

PROC WS3
if WS3 = 995 then
  skip to WS5
elseif WS3 < 995 and WS3%10 <> 0 and WS3%10 <> 5 then
  errmsg(9993)
endif;

PROC WS5
if WS5 <> 1 then
  skip to WS7
endif;

PROC WS6
alphavar = $;
if alphachk("ABCDEFXZ") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;
{ Check "Don't Know" is only response }
if pos("Z",$) then
  if alphsize > 1 then
    errmsg(9996);
    reenter
  endif;
endif;

PROC WS6AAA
if WS6AAA < 3 then
  skip to WS7
endif;
PROC WS6AAB
if $ >= HH11 then
  errmsg(0017);
  reenter
endif;
PROC WS7
if WS7 = 95 then
  endgroup
endif;

PROC WS8
if WS8 <> 1 then
  endgroup
endif;

PROC WMCH
{ *** Level 2 *** }
preproc
  { Initialization prior to an individual questionnaire }
  xline = 0;
  { Find the next eligible woman to enter }
  i = 1;
  while i <= HH11 do
    if HL6(i) and wenter(i) = 0 then
      xline = i;
      i = HH11;  { Having found a woman exit the while-do loop }
    endif;
    i = i + 1;
  enddo;
  if !xline then { !xline es lo mismo que xline<>0 }
    { Find the next eligible child to enter }
    i = 1;
    while i <= HH11 do
      if HL8(i) and wenter(i) = 0 then
        xline = i;
        i = HH11;  { Having found a child exit the while-do loop }
      endif;
      i = i + 1;
    enddo;
  endif;
  { Quit level 2 if no individual questionnaires to enter }
  if !xline then
    endlevel
  endif;

postproc
  { Updating of information after completion of an individual questionnaire }

  { Update the entry flag for individual questionnaire just entered }
  if xline then
    if HL6(xline) <> 0 then
      wenter(xline) = 1
    elseif HL8(xline) <> 0 then
      wenter(xline) = 2
    endif;
  endif;

  { Check the number of individual questionnaires entered and
    quit level 2 if no more to enter }
  xwomen = 0;
  do varying i = 1 until i > HH11
    if wenter(i) = 1 then
      xwomen = xwomen + 1
    endif;
  enddo;
  xchild = 0;
  do varying i = 1 until i > HH11
    if wenter(i) = 2 then
      xchild = xchild + 1
    endif;
  enddo;

  if xwomen = HH12 and xchild = HH14 then
    endlevel
  endif;

PROC LN
preproc
LN = xline;

postproc
if HL8(LN) <> 0 then
  skip to FORMCH
endif;

PROC WM1
preproc
WM1 = HH1;
WM2 = HH2;

PROC WM4
preproc
if addmode then
  display(concat("Cuestionario para Mujer",edit("99", LN)));
endif;

postproc
if WM4 <> LN then
  errmsg(1000,"Mujer",LN);
  reenter
endif;


PROC WM6Y
recode WM6Y   :     WM6M        : WM6D => err;
   		2006 : 1,3,5,7         : 1-31 => 0;
   		2006 : 4,6             : 1-30 => 0;
   		2006 : 2               : 1-28 => 0;
     	     :                 :      => 1;
endrecode;
if err then
  errmsg(0016);
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ddw= (WM6Y*100 + WM6M)*100 + WM6D;
ss = sysdate("yyyymmdd");
if ddw >= ss or ddw < dd then
  errmsg(0016);
  reenter
endif;
diwm = cmcode(WM6M,WM6Y);

PROC WM7
if WM7 <> 1 then
  if endmess() then
    reenter
  endif;
  endlevel
endif;

PROC WM8Y
udob = diwm - minage*12;
ldob = diwm - maxage*12 - 11;
if WM8Y < 9997 then
  ldob = setlb(WM8M,WM8Y,0);
  udob = setub(WM8M,WM8Y,9999);
  if udob < diwm - maxage*12 - 11 or ldob > diwm - minage*12 then
    errmsg(1001);
  { reenter }
  endif;
endif;

PROC WM9
if WM9 <> HL5(WM4) then
  errmsg(1002,WM9,HL5(LN));
endif;
{ Lower bound of CMC date of birth }
t = adjlba(ldob,udob,diwm,diwm,WM9);
if t < 0 then
  errmsg(1003);
{ reenter }
else
  ldob = t
endif;
{ Upper bound of CMC date of birth }
t = adjuba(ldob,udob,diwm,diwm,WM9);
if t < 0 then
  errmsg(1003);
{ reenter }
else
  udob = t
endif;

PROC WM10
if WM10 <> ED2(LN) and ED3(LN) <> 0 then {NEW}
  errmsg(1011,ED2(LN),WM10);
endif;
if WM10 <> 1 then
  endgroup;
endif;

PROC WM11
if WM11 <> ED3A(LN) then {NEW}
  errmsg(1012,ED3A(LN),WM11);
endif;

PROC WM12
if WM12 <> ED3B(LN) then {NEW}
  errmsg(1013,ED3B(LN),WM12);
endif;
lev = WM11;
grd = WM12;
recode lev  : grd         => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          0 : 0-1	  => 0;   {Preescolar }
          1 : 0-6         => 0;   { Primary }
          2 : 0-3         => 0;   { Secondary }
          3 : 0-5         => 0;   { Obrero }
          4 : 0-5	  => 0;   {Preuniv}
          5 : 0-7         => 0;   { Superior }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
endrecode;
if err then
  errmsg(1014);
  { reenter }
endif;
{ WM13 Filter }
if WM11 in 2,3 then
  endgroup
endif;

PROC CP1
if CP1  <> 1 then
  skip to CP2
endif;

PROC CP1A
skip to CP4A

PROC CP2
if CP2 <> 1 then
  skip to CP4A
endif;

PROC CP3
alphavar = $;
if alphachk("ABCDEFGHIJKLMX") then
  errmsg(9998);
  reenter
else
  $ = alphavar;
endif;

PROC CP4A
if CP4A  = 3 then
  endgroup
elseif CP4A <> 1 then
  skip to CP4E
endif;
PROC CP4CN
recode CP4CU  : CP4CN       => err;
          1,2 : 0-90,99     => 0;   { Months, Years }
          9   : 93-96,98,99 => 0;   { Special, DK, Missing }
              :             => 1;
endrecode;
if err then
  errmsg(9992);
  reenter
endif;

if CP4CU = 9 and CP4CN = 94 then
  endgroup
endif;
PROC CP4E
preproc
if CP1 = 1 then
  endgroup
endif;
PROC FORMHA
if endmess() then
  if HA1 <> 1 then
    reenter HA1
  else
  	if HA15 <> 1 then
    	reenter HA18
    else
    	reenter HA17
    endif;
  endif;
endif;
endlevel;

PROC HA1
if HA1 <> 1 then
  endgroup
endif;

PROC HA15
if HA15 <> 1 then
  skip to HA18
endif;

PROC HA17
if $ <> 4 then
  endgroup;
endif;
PROC HA18
endgroup
PROC UF1
preproc
UF1 = HH1;
UF2 = HH2;

PROC UF4
preproc
if addmode then
  display(concat("Cuestionario para nio ",edit("99", (LN))));
endif;

postproc
if UF4 <> (LN) then
  errmsg(2000,"nio",(LN));
  reenter
endif;

PROC UF6
if HL8(LN) <> UF6 then
  errmsg(2004,UF6,HL8(LN));
  { Critical var; enforce consistency during editing }
  reenter;
endif;

PROC UF8Y
recode  UF8Y  :     UF8M        : UF8D => err;
   	 2006 : 1,3,5,7         : 1-31 => 0;
   	 2006 : 4,6             : 1-30 => 0;
   	 2006 : 2               : 1-28 => 0;
     	      :                 :      => 1;
endrecode;
if err then
  errmsg(0016);
  reenter
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ddw= (UF8Y*100 + UF8M)*100 + UF8D;
ss = sysdate("yyyymmdd");
if ddw >= ss or ddw < dd then
  errmsg(0016);
  reenter
endif;
dich = cmcode(UF8M,UF8Y);

PROC UF9
if UF9 <> 1 then
  if endmess() then
    reenter
  endif;
  endlevel
endif;

PROC UF10Y
udob = dich;
ldob = dich - chhlth*12 - 11;
if UF10Y < 9997 then
  ldob = setlb(UF10M,UF10Y,0);
  udob = setub(UF10M,UF10Y,9999);
  if udob < dich - chhlth*12 - 11 or ldob > dich then
    errmsg(2001);
  { reenter }
  endif;
endif;

PROC UF11
if UF11 <> HL5(UF4) then
  errmsg(2002,UF11,HL5(LN));
endif;
{ Lower bound of CMC date of birth }
t = adjlba(ldob,udob,dich,dich,UF11);
if t < 0 then
  errmsg(2003);
{ reenter }
else
  ldob = t
endif;
{ Upper bound of CMC date of birth }
t = adjuba(ldob,udob,dich,dich,UF11);
if t < 0 then
  errmsg(2003);
{ reenter }
else
  udob = t
endif;

PROC BF1
if BF1 <> 1 then
  skip to BF3A
endif;

PROC BF3H
{ BF4 Filter }
if BF3H <> 1 then
  endgroup
endif;
PROC IM1
if $ <> 1 then
	skip to IM10;
endif;

PROC IM2D
if IM2D = 0 or IM2D = 44 or IM2D = 66 then
  skip to IM3A1D;
endif;


PROC IM2A
if im2a=1 then
skip to IM3A1D;
ENDIF;
PROC IM3A1D
preproc
if vdvalid(IM2D,IM2M,IM2Y) then
  errmsg(2701,"BCG",IM2D,IM2M,IM2Y);
elseif vdoi(IM2D,IM2M,IM2Y) then
  errmsg(2702,"BCG",IM2D,IM2M,IM2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM2D,IM2M,IM2Y) then
  errmsg(2703,"BCG",IM2D,IM2M,IM2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?}
if IM3A1D = 0 or IM3A1D = 44 or IM3A1D = 66 then
  skip to IM3B1D;
endif;
PROC IM3A1A
if IM3A1A=1 then
skip to IM3B1D;
ENDIF;
PROC IM3B1D
preproc
if vdvalid(IM3A1D,IM3A1M,IM3A1Y) then
  errmsg(2701,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y);
elseif vdoi(IM3A1D,IM3A1M,IM3A1Y) then
  errmsg(2702,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3A1D,IM3A1M,IM3A1Y) then
  errmsg(2703,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?}
if IM3B1D = 0 or IM3B1D = 44 or IM3B1D = 66 then
  skip to IM3C1D;
endif;
PROC IM3B1A
if IM3B1A=1 then
skip to IM3C1D;
ENDIF;
PROC IM3C1D
preproc
if vdvalid(IM3B1D,IM3B1M,IM3B1Y) then
  errmsg(2701,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y);
elseif vdoi(IM3B1D,IM3B1M,IM3B1Y) then
  errmsg(2702,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3B1D,IM3B1M,IM3B1Y) then
  errmsg(2703,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?}
if IM3C1D = 0 or IM3C1D = 44 or IM3C1D = 66 then
  skip to IM3D1D;
endif;
PROC IM3C1A
if IM3C1A=1 then
skip to IM3D1D;
ENDIF;
PROC IM3D1D
preproc
if vdvalid(IM3C1D,IM3C1M,IM3C1Y) then
  errmsg(2701,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y);
elseif vdoi(IM3C1D,IM3C1M,IM3C1Y) then
  errmsg(2702,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3C1D,IM3C1M,IM3C1Y) then
  errmsg(2703,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?}
if IM3D1D = 0 or IM3D1D = 44 or IM3D1D = 66 then
  skip to IM3A2D;
endif;
PROC IM3D1A
if IM3D1A=1 then
skip to IM3A2D;
ENDIF;
PROC IM3A2D
preproc
if vdvalid(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2701,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y);
elseif vdoi(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2702,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3D1D,IM3D1M,IM3D1Y) then
  errmsg(2703,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?}
if IM3A2D = 0 or IM3A2D = 44 or IM3A2D = 66 then
  skip to IM3B2D;
endif;
PROC IM3A2A
if IM3A2A=1 then
skip to IM3B2D;
ENDIF;
PROC IM3B2D
preproc
if vdvalid(IM3A2D,IM3A2M,IM3A2Y) then
  errmsg(2701,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y);
elseif vdoi(IM3A2D,IM3A2M,IM3A2Y) then
  errmsg(2702,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3A2D,IM3A2M,IM3A2Y) then
  errmsg(2703,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM3B2D = 0 or IM3B2D = 44 or IM3B2D = 66 then
  skip to IM3C2D;
endif;
PROC IM3B2A
if IM3B2A=1 then
skip to IM3C2D;
ENDIF;
PROC IM3C2D
preproc
if vdvalid(IM3B2D,IM3B2M,IM3B2Y) then
  errmsg(2701,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y);
elseif vdoi(IM3B2D,IM3B2M,IM3B2Y) then
  errmsg(2702,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3B2D,IM3B2M,IM3B2Y) then
  errmsg(2703,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM3C2D = 0 or IM3C2D = 44 or IM3C2D = 66 then
  skip to IM4A1D;
endif;
PROC IM3C2A
if IM3C2A=1 then
skip to IM4A1D;
ENDIF;
PROC IM4A1D
preproc

if vdvalid(IM3C2D,IM3C2M,IM3C2Y) then
  errmsg(2701,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y);
elseif vdoi(IM3C2D,IM3C2M,IM3C2Y) then
  errmsg(2702,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM3C2D,IM3C2M,IM3C2Y) then
  errmsg(2703,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4A1D = 0 or IM4A1D = 44 or IM4A1D = 66 then
  skip to IM4B1D;
endif;
PROC IM4A1A
if IM4A1A=1 then
skip to IM4B1D;
ENDIF;
PROC IM4B1D
preproc

if vdvalid(IM4A1D,IM4A1M,IM4A1Y) then
  errmsg(2701,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y);
elseif vdoi(IM4A1D,IM4A1M,IM4A1Y) then
  errmsg(2702,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4A1D,IM4A1M,IM4A1Y) then
  errmsg(2703,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4B1D = 0 or IM4B1D = 44 or IM4B1D = 66 then
  skip to IM4C1D;
endif;
PROC IM4B1A
if IM4B1A=1 then
skip to IM4C1D;
ENDIF;
PROC IM4C1D
preproc
if vdvalid(IM4B1D,IM4B1M,IM4B1Y) then
  errmsg(2701,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y);
elseif vdoi(IM4B1D,IM4B1M,IM4B1Y) then
  errmsg(2702,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4B1D,IM4B1M,IM4B1Y) then
  errmsg(2703,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4C1D = 0 or IM4C1D = 44 or IM4C1D = 66 then
  skip to IM4A2D;
endif;
PROC IM4C1A
if IM4C1A=1 then
skip to IM4A2D;
ENDIF;
PROC IM4A2D
preproc

if vdvalid(IM4C1D,IM4C1M,IM4C1Y) then
  errmsg(2701,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y);
elseif vdoi(IM4C1D,IM4C1M,IM4C1Y) then
  errmsg(2702,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4C1D,IM4C1M,IM4C1Y) then
  errmsg(2703,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4A2D = 0 or IM4A2D = 44 or IM4A2D = 66 then
  skip to IM4B2D;
endif;
PROC IM4A2A
if IM4A2A=1 then
skip to IM4B2D;
ENDIF;
PROC IM4B2D
preproc

if vdvalid(IM4A2D,IM4A2M,IM4A2Y) then
  errmsg(2701,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y);
elseif vdoi(IM4A2D,IM4A2M,IM4A2Y) then
  errmsg(2702,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4A2D,IM4A2M,IM4A2Y) then
  errmsg(2703,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4B2D = 0 or IM4B2D = 44 or IM4B2D = 66 then
  skip to IM4C2D;
endif;
PROC IM4B2A
if IM4B2A=1 then
skip to IM4C2D;
ENDIF;
PROC IM4C2D
preproc

if vdvalid(IM4B2D,IM4B2M,IM4B2Y) then
  errmsg(2701,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y);
elseif vdoi(IM4B2D,IM4B2M,IM4B2Y) then
  errmsg(2702,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4B2D,IM4B2M,IM4B2Y) then
  errmsg(2703,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4C2D = 0 or IM4C2D = 44 or IM4C2D = 66 then
  skip to IM4DD;
endif;
PROC IM4C2A
if IM4C2A=1 then
skip to IM4DD;
ENDIF;
PROC IM4DD
preproc
if vdvalid(IM4C2D,IM4C2M,IM4C2Y) then
  errmsg(2701,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y);
elseif vdoi(IM4C2D,IM4C2M,IM4C2Y) then
  errmsg(2702,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y,UF8D,UF8M,UF8Y);
elseif vdob(IM4C2D,IM4C2M,IM4C2Y) then
  errmsg(2703,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM4DD = 0 or IM4DD = 44 or IM4DD = 66 then
  skip to IM5AD;
endif;
PROC IM4DA
if IM4DA=1 then
skip to IM5AD;
ENDIF;
PROC IM5AD
preproc
if vdvalid(IM4DD,IM4DM,IM4DY) then
  errmsg(2701,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY);
elseif vdoi(IM4DD,IM4DM,IM4DY) then
  errmsg(2702,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY,UF8D,UF8M,UF8Y);
elseif vdob(IM4DD,IM4DM,IM4DY) then
  errmsg(2703,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM5AD = 0 or IM5AD = 44 or IM5AD = 66 then
  skip to IM5BD;
endif;
PROC IM5AA
if IM5AA=1 then
skip to IM5BD;
ENDIF;
PROC IM5BD
preproc
if vdvalid(IM5AD,IM5AM,IM5AY) then
  errmsg(2701,"Hib 2 meses",IM5AD,IM5AM,IM5AY);
elseif vdoi(IM5AD,IM5AM,IM5AY) then
  errmsg(2702,"Hib 2 meses",IM5AD,IM5AM,IM5AY,UF8D,UF8M,UF8Y);
elseif vdob(IM5AD,IM5AM,IM5AY) then
  errmsg(2703,"Hib 2 meses",IM5AD,IM5AM,IM5AY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM5BD = 0 or IM5BD = 44 or IM5BD = 66 then
  skip to IM5CD;
endif;
PROC IM5BA
if IM5BA=1 then
skip to IM5CD;
ENDIF;
PROC IM5CD
preproc
if vdvalid(IM5BD,IM5BM,IM5BY) then
  errmsg(2701,"Hib 4 Meses",IM5BD,IM5BM,IM5BY);
elseif vdoi(IM5BD,IM5BM,IM5BY) then
  errmsg(2702,"Hib 4 Meses",IM5BD,IM5BM,IM5BY,UF8D,UF8M,UF8Y);
elseif vdob(IM5BD,IM5BM,IM5BY) then
  errmsg(2703,"Hib 4 Meses",IM5BD,IM5BM,IM5BY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM5CD = 0 or IM5CD = 44 or IM5CD = 66 then
  skip to IM5DD;
endif;
PROC IM5CA
if IM5CA=1 then
skip to IM5DD;
ENDIF;
PROC IM5DD
preproc
if vdvalid(IM5CD,IM5CM,IM5CY) then
  errmsg(2701,"Hib 6 Meses",IM5CD,IM5CM,IM5CY);
elseif vdoi(IM5CD,IM5CM,IM5CY) then
  errmsg(2702,"Hib 6 Meses",IM5CD,IM5CM,IM5CY,UF8D,UF8M,UF8Y);
elseif vdob(IM5CD,IM5CM,IM5CY) then
  errmsg(2703,"Hib 6 Meses",IM5CD,IM5CM,IM5CY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM5DD = 0 or IM5DD = 44 or IM5DD = 66 then
  skip to IM6AD;
endif;
PROC IM5DA
if IM5DA=1 then
skip to IM6AD;
ENDIF;
PROC IM6AD
preproc
if vdvalid(IM5DD,IM5DM,IM5DY) then
  errmsg(2701,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY);
elseif vdoi(IM5DD,IM5DM,IM5DY) then
  errmsg(2702,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY,UF8D,UF8M,UF8Y);
elseif vdob(IM5DD,IM5DM,IM5DY) then
  errmsg(2703,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM6AD = 0 or IM6AD = 44 or IM6AD = 66 then
  skip to IM6BD;
endif;
PROC IM6AA
if IM6AA=1 then
skip to IM6BD;
ENDIF;
PROC IM6BD
preproc
if vdvalid(IM6AD,IM6AM,IM6AY) then
  errmsg(2701,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY);
elseif vdoi(IM6AD,IM6AM,IM6AY) then
  errmsg(2702,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY,UF8D,UF8M,UF8Y);
elseif vdob(IM6AD,IM6AM,IM6AY) then
  errmsg(2703,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM6BD = 0 or IM6BD = 44 or IM6BD = 66 then
  skip to IM7D;
endif;
PROC IM6BA
if IM6BA=1 then
skip to IM7D;
ENDIF;
PROC IM7D
preproc
if vdvalid(IM6BD,IM6BM,IM6BY) then
  errmsg(2701,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY);
elseif vdoi(IM6BD,IM6BM,IM6BY) then
  errmsg(2702,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY,UF8D,UF8M,UF8Y);
elseif vdob(IM6BD,IM6BM,IM6BY) then
  errmsg(2703,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM7D = 0 or IM7D = 44 or IM7D = 66 then
  skip to IM8AD;
endif;
PROC IM7A
if IM7A=1 then
skip to IM8AD;
ENDIF;
PROC IM8AD
preproc
if vdvalid(IM7D,IM7M,IM7Y) then
  errmsg(2701,"PRS",IM7D,IM7M,IM7Y);
elseif vdoi(IM7D,IM7M,IM7Y) then
  errmsg(2702,"PRS",IM7D,IM7M,IM7Y,UF8D,UF8M,UF8Y);
elseif vdob(IM7D,IM7M,IM7Y) then
  errmsg(2703,"PRS",IM7D,IM7M,IM7Y,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM8AD = 0 or IM8AD = 44 or IM8AD = 66 then
  skip to IM8BD;
endif;
PROC IM8AA
if IM8AA=1 then
skip to IM8BD;
ENDIF;
PROC IM8BD
preproc
if vdvalid(IM8AD,IM8AM,IM8AY) then
  errmsg(2701,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY);
elseif vdoi(IM8AD,IM8AM,IM8AY) then
  errmsg(2702,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY,UF8D,UF8M,UF8Y);
elseif vdob(IM8AD,IM8AM,IM8AY) then
  errmsg(2703,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM8BD = 0 or IM8BD = 44 or IM8BD = 66 then
  skip to IM8CD;
endif;
PROC IM8BA
if IM8BA=1 then
skip to IM8CD;
ENDIF;
PROC IM8CD
preproc
if vdvalid(IM8BD,IM8BM,IM8BY) then
  errmsg(2701,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY);
elseif vdoi(IM8BD,IM8BM,IM8BY) then
  errmsg(2702,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY,UF8D,UF8M,UF8Y);
elseif vdob(IM8BD,IM8BM,IM8BY) then
  errmsg(2703,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM8CD = 0 or IM8CD = 44 or IM8CD = 66 then
  skip to IM8DD;
endif;
PROC IM8CA
if IM8CA=1 then
skip to IM8DD;
ENDIF;
PROC IM8DD
preproc
if vdvalid(IM8CD,IM8CM,IM8CY) then
  errmsg(2701,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY);
elseif vdoi(IM8CD,IM8CM,IM8CY) then
  errmsg(2702,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY,UF8D,UF8M,UF8Y);
elseif vdob(IM8CD,IM8CM,IM8CY) then
  errmsg(2703,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY,UF10D,UF10M,UF10Y);
endif;

postproc {No sigue si es 44 o 66?, debe seguir a la pregunta de la fecha}
if IM8DD = 0 or IM8DD = 44 or IM8DD = 66 then
  skip to IM9;
endif;
PROC IM8DA
if IM8DA=1 then
skip to IM9;
ENDIF;
PROC IM9
preproc
if vdvalid(IM8DD,IM8DM,IM8DY) then
  errmsg(2701,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY);
elseif vdoi(IM8DD,IM8DM,IM8DY) then
  errmsg(2702,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY,UF8D,UF8M,UF8Y);
elseif vdob(IM8DD,IM8DM,IM8DY) then
  errmsg(2703,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY,UF10D,UF10M,UF10Y);
endif;
postproc

skip to IM24A;

PROC IM10
if IM10 <> 1 then
	skip to IM24A;
  ENDIF; 

PROC IM12
if IM12 <> 1 then
  skip to IM15
endif;

PROC IM15
if IM15 <> 1 then
  skip to IM17
endif;

PROC IM17
if IM17 <> 1 then
  skip to IM19
endif;

PROC IM19
if IM19 <> 1 then
  skip to IM21
endif;

PROC IM21
if IM21 <> 1 then
  skip to IM23
endif;

PROC IM27
if IM27 <> 1 then
  endgroup;
endif;

PROC IM27A
if $ <> 2 then
  endgroup;
endif;
PROC IM27B
endgroup
