PROC GLOBAL
set explicit;
{ Working variables -- check the lengths needed for all fields }
alpha(40) CSPro;                                        { CSPro executables directory !Modificado a 33 de 32 }
alpha(26) proj;                                         { project directory name }
alpha(8)  app, dic;                                     { application name and dictionary name }
alpha(8)  opid;                                         { operator ID }
alpha(30) floppy;                       { !!! TRANSFER !!! make sure length of variable to store transfer drive is long enough }
alpha(2)  wrkdrv;                   { length of var to store workdrive letters, e.g. "C:" }
alpha(40) wrkprj, data, veri, xdir; { directories }
alpha(8)  entry, dicts;             { directory names for ENTRY, DICTS -- suggest using these names }
alpha(3)  xcluster;                 { !!! CLUSTER !!! make sure length is correct }
alpha(2)  fcodes;                   { file codes - M = Main, V = Verification }
alpha(2)  hcodes;                   { code for household data file name }

numeric always, choice, chkok, err;

file pfffile mdata vdata datacopy jstone dirname;

{ ---------------------------------------------------------------------------- }

function chkdir()
  setfile(dirname,xdir);
  if fileexist(xdir) <> 1 then
    errmsg("El directorio %s no existe",xdir);
    stop(-1);
  endif;
end;

function chkexist(addmode,mainver)
  chkok = 1;
  if mainver = 1 then {if main data}
    if !fileexist(mdata) & !addmode then {main data doesn't exist and in modify mode}
      errmsg("Archivo principal para el consultorio %s no existe  - use Opcion %s",xcluster,"A");
      chkok = 0;
    endif;
  else {if verification data}
    if !fileexist(vdata) & !addmode then {verification data doesn't exist and in modify mode}
      errmsg("El archivo de datos verificados para el consultorio %s no existe  - use Opcion %s",xcluster,"R");
      chkok = 0;
    endif;
    if chkok then {if verification data file exists on this machine...}
      if fileexist(mdata) then {...AND main data file exists on this machine}
        errmsg("El consultorio %s no puede ser verificado en esta maquina",xcluster);
        chkok = 0; {prevent data entry}
      endif;
    endif;
  endif;
  chkexist = chkok;
end;

function genpff(addmode,mainver)
  filecreate(pfffile);
  filewrite(pfffile, "[Run Information]");
  filewrite(pfffile, "Version=CSPro 2.6");
  filewrite(pfffile, "AppType=Entry");
  filewrite(pfffile, "");
  filewrite(pfffile, "[DataEntryInit]");
  filewrite(pfffile, concat("OperatorID=", strip(opid)));
  if addmode then
    filewrite(pfffile, "StartMode=ADD");
    filewrite(pfffile, "Lock=Verify");
    filewrite(pfffile, "Fullscreen=Yes");
  else
    { no StartMode for modify }
    filewrite(pfffile, "Lock=Add,Verify");
  endif;
  filewrite(pfffile, "NoFileOpen=Yes");
  filewrite(pfffile, "");
  filewrite(pfffile, "[Files]");
  filewrite(pfffile, concat("Application=", strip(wrkprj), "\", strip(entry), "\", strip(app), ".ent"));
  if mainver = 1 then
    filewrite(pfffile, concat("InputData=", strip(data), "\", hcodes, xcluster, fcodes[mainver:1], ".DAT"));
  else
    filewrite(pfffile, concat("InputData=", strip(veri), "\", hcodes, xcluster, fcodes[mainver:1], ".DAT"));
  endif;
  filewrite(pfffile, "");
  filewrite(pfffile, "[Parameters]");
  filewrite(pfffile, concat("Parameter=", xcluster));
  close(pfffile);
end;

function runpff();
  { Using single quotes instad of double quotes as double quotes are needed in the string generated }
  Execsystem(concat('"', strip(cspro), '\CSEntry.exe" ',
                    strip(wrkprj), "\", strip(entry), "\", strip(app), '.pff'),
             maximized,wait);
end;

function csrun(addmode,mainver)
  if chkexist(addmode,mainver) then
    genpff(addmode,mainver);
    runpff();
  { backupf(mainver); -- not used for now }
  endif;
end;

function transfer(mainver)
  { !!! NETWORK !!! remove message if using a network}
  errmsg("*** Inserte diskette con datos en el drive %s",floppy);
  setfile(datacopy,concat(strip(floppy), "\",hcodes,xcluster, fcodes[mainver  :1],  ".dat"));
  if mainver = 1 then { if the main data }
    if fileexist(mdata) then
      setfile(datacopy,concat(strip(floppy), "\",hcodes,xcluster, fcodes[mainver  :1],  ".dat"));
      if fileexist(datacopy) then
        errmsg("*** El archivo principal de datos para el consultorio %s ya existe en el drive %s -- Verifique",xcluster,floppy);
      endif;
      filecopy(mdata,datacopy);
      { !!! NETWORK !!! change wording of message if using a network }
      errmsg("El archivo de datos del consultorio %s fue copiado a diskette",xcluster);
    else
      errmsg("El archivo de datos del consultorio %s no existe en esta maquina",xcluster);
    endif;
  else {if the verification data }
    if fileexist(vdata) then
      setfile(datacopy,concat(strip(floppy), "\",hcodes,xcluster, fcodes[mainver  :1],  ".dat"));
      if fileexist(datacopy) then
        errmsg("*** El archivo de datos verificados del consultorio %s ya existe en el drive %s -- Verifique",xcluster,floppy);
      endif;
      filecopy(vdata,datacopy);
      { !!! NETWORK !!! change wording of message if using a network }
      errmsg("Archivo de datos verificados del consultorio %s fue copiado a diskette",xcluster);
    else
      errmsg("Archivo de datos verificados del consultorio %s no existe en esta maquina",xcluster);
    endif;
  endif
end;

PROC ENTER_FF
preproc
{ The following directories are assumed }
{ \MICS        Main survey directory (some files located here)}
{ \MICS\ENTRY  Data entry programs located here               }
{ \MICS\DICTS  Directory used to store dictionaries           }
{ \MICS\DATA   Directory used to store data                   }
{ \MICS\VERI   Directory used to store verification data      }

{CSPro="C:\Program Files\CSPro 2.6";     { CSPRO directory }}
CSPro="C:\Archivos de Programa\CSPro 2.6";      {CSPRO directory in Spanish }
proj="MICS\CSPRO";                                      { Project directory }
app="ENTRY";                                            { Entry application name }
dic="MICS3";                                            { Dictionary name }
opid="MICS";                                            { Operator ID }
floppy="C:\MICS3\datos";                                            { !!! NETWORK !!! if using network, change "A:" to shared directory }
fcodes = "MV";                                          { File codes - M = Main, V = Verification,) }
hcodes = "HH";                                          { Prefix of data file name, e.g. HH001M.DAT }
wrkdrv="C:";                                            { Set work drive }
wrkprj=concat(strip(wrkdrv), "\", PROJ);
data=concat(strip(wrkprj), "\DATA");{ Main data directory }
veri=concat(strip(wrkprj), "\VERI");{ Verification data directory }
entry="Entry";                                          { Entry programs directory name }
dicts="Dicts";                                          { Dictionry directory name }

{ Check that all directories needed exist }
xdir = wrkprj; chkdir();
xdir = concat(strip(wrkprj), "\", strip(entry)); chkdir();
xdir = concat(strip(wrkprj), "\", strip(dicts)); chkdir();
xdir = data; chkdir();
xdir = veri; chkdir();

{ create the file name variable justone}
setfile(jstone,concat(strip(wrkprj),"\justone.txt"));

{ Check that there are not two concurrent sessions of CSPro loaded at the same time }
if fileexist(jstone) then
      errmsg("Hay otra sesion de entrada de datos corriendo o la computadora aborto mientras corria");
  if accept("Restaura","Si","No") = 1 then
    filedelete(jstone)
  else
    stop(-1);
  endif;
endif;
{ create the file justone [it is deleted when option 11, quit, is selected by the DE operator }
setfile(jstone,concat(strip(wrkprj),"\justone.txt"),create);

PROC ECLUSTER
{ !!! CLUSTER !!! check that cluster entered is valid }
recode ecluster => err;
        001-501 => 0;     { Give list of valid cluster Cuba }
       { 001-032 => 0;    { Give list of valid cluster Pinar }}
	   { 033-064 => 0;    { Give list of valid cluster P Habana }}
       { 065-163 => 0;    { Give list of valid cluster C. Hab }}
       { 164-193 => 0;    { Give list of valid cluster Mat }}
       { 194-230 => 0;    { Give list of valid cluster V. Clara }}
       { 231-248 => 0;    { Give list of valid cluster Cienf }}
       { 249-269 => 0;    { Give list of valid cluster Sancti Spritus }}
       { 270-287 => 0;    { Give list of valid cluster Ciego de Avila }}
       { 288-322 => 0;    { Give list of valid cluster Camagey }}
       { 323-345 => 0;    { Give list of valid cluster Las Tunas }}
       { 346-391 => 0;    { Give list of valid cluster Holgun }}
       { 392-428 => 0;    { Give list of valid cluster Granma }}
       { 429-474 => 0;    { Give list of valid cluster Santiago de Cuba }}
       { 475-497 => 0;    { Give list of valid cluster Guantnamo }}
       { 498-501 => 0;    { Give list of valid cluster Isla de la Juventud }}
                => 1;
endrecode;
if err then
  display("El numero del consultorio no es valido para su provincia");
  reenter;
endif;
{ !!! CLUSTER !!! check length of edit pattern matches length of largest cluster number }
xcluster = edit("999",$);
{ set cluster data file names }
setfile(mdata,concat(strip(data), "\",hcodes, xcluster, "M", ".DAT"));
setfile(vdata,concat(strip(veri), "\",hcodes, xcluster, "V", ".DAT"));
{ set ppf file name }
setfile(pfffile,concat(strip(wrkprj), "\", strip(entry), "\", strip(app), ".pff"));
{ set name of file that helps make sure that only one version of CSPRO runs at a time }
setfile(jstone,concat(strip(wrkprj),"\justone.txt"));
{ set name of the project directory }
setfile(dirname,wrkprj);
close(dirname);

always = 1;
while always do   { loop forever }
  { Get the selected option }
  { !!! NETWORK !!! replace "diskette" in options T and V with "network" }
  choice = accept("Opciones del Menu de Entrada",
                  "A  Agregar datos al archivo ...................A",
                  "M  Modificacion del archivo de datos...........M",
                  "T  Transferir datos al diskette................T",
                  "------------------------------------------------",
                  "R  Re-ingresar datos para verificacion.........R",
                  "U  Actualizar datos verificados................U",
                  "V  Transferir datos verificados al diskette....V",
                  "------------------------------------------------",
                  "N  Nuevo numero de Consultorio.................N",
                  "Q  Abandonar/salir.............................Q");

      if choice =  0 then {ESC} reenter; { escape from menu & allow entry of new cluster number }
  elseif choice =  1 then {ADD} csrun(1,1); {Main}
  elseif choice =  2 then {MOD} csrun(0,1); {Main}
  elseif choice =  3 then Transfer(1);          {Main}
  elseif choice =  4 then {---} { do nothing }
  elseif choice =  5 then {ADD} csrun(1,2); {Verification}
  elseif choice =  6 then {MOD} csrun(0,2); {Verification}
  elseif choice =  7 then Transfer(2);          {Verification}
  elseif choice =  8 then {---} { do nothing }
  elseif choice =  9 then {NEW} reenter; { get the new cluster number }
  elseif choice = 10 then {QUIT}
    if fileexist(jstone) then
      filedelete(jstone);
    endif;
    stop(-1);       { quit the process }
  endif;
enddo;
