PROC GLOBAL

{ --------------------------------------------------------------------------- }

set explicit;
{ Working variables }

numeric zscoeff zsr zsb1 zsb2 zsb3 zsb4 zsb5 zsdz zst
  zsdzp zsfx zsll zsul zsa zsknot zsi zsj zsk zsl
  zsz zsc zsy1 zsy2 zsy3 zssd1 zssd2 zshta
  zspmed zsv zshac zshap zshaz zswap zswaz zswac zshtw
  zswhp zswhz zswhc fhaz fwaz fwhz zsflag leapday x
  xdays1 y xdays2 vcheckx addmode qmark lx l totlen
  aok alphsize a maxmem maxovc hhnum minage maxage minab
  chhlth chlabl chlabu mindi cln err i dd ss
  di lev grd numovc j xline xwomen xchild
  ddw diwm udob ldob t ldobfc udobfc ldoblc udoblc
  dich hwsex hwage hwerr birthd birthm
  birthy age xweight xheight
  rok xmother momhl3 memhl3 mline_valid xfather dadhl3 fline_valid
  ldofm udofm minam frstrun cnt schema1 schema2;

{ --------------------------------------------------------------------------- }

function valid(xvar);
  valid = (!special(xvar) and xvar < 96)
end;

function NAtoZero(xvar);
  if xvar = notappl then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

{ --------------------------------------------------------------------------- }

  function agemth(xhwbd,xhwbm,xhwby,xhwmd,xhwmm,xhwmy);
    { if birth month and year and measurement day, month and year are all valid }
    if valid(xhwbd) and valid(xhwbm) and valid(xhwmd) and valid(xhwmm) and xhwmy < 9996 then
      { if day of birth inconsistent, don't know or missing }
      if not(valid(xhwbd)) then
        { impute day of birth }
        xhwbd = 15;
      endif;
      leapday = (xhwby % 4 = 0);
      x = 1;
      xdays1 = xhwbd;
      while x < xhwbm do
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays1 = xdays1 + y;
        x = x + 1
      enddo;
      leapday = (xhwmy % 4 = 0);
      x = 1;
      xdays2 = xhwmd;
      while x < xhwmm do
        recode x        => y;
           1,3,5,7,8,10 => 31;
                      2 => 28+leapday;
               4,6,9,11 => 30;
        endrecode;
        xdays2 = xdays2 + y;
        x = x + 1
      enddo;
      x = xhwby;
      while x < xhwmy do
        xdays2 = xdays2 + 365 + (x % 4 = 0);
        x = x + 1
      enddo;
      agemth = int(((xdays2 - xdays1)/30.4375)*100+0.5)/100;
    else
      agemth = 9999;
    endif;
  end;

{ --------------------------------------------------------------------------- }

{ Function to check all possible combinations of day, month and year }
function vdvalid(vcheckd,vcheckm,vchecky);
  { 0 = no problem, 1 = inconsistency }
  vdvalid = 0;
  { Check day, month and year are consistent }
  recode    vchecky   : vcheckm               : vcheckd    => vcheckx; { !!! }
  2000-2006,9996-9999 : 1,3,5,7,8,10,12,96-99 : 1-31,96-99 => 0;
  2000-2006,9996-9999 : 4,6,9,11              : 1-30,96-99 => 0;
  2000-2006,9996-9999 : 2                     : 1-28,96-99 => 0;
  2000,2004           : 2                     : 29         => 0;       { leap year }
              notappl : notappl               : 66         => 0;
              notappl : notappl               : 44         => 0;
              notappl : notappl               : 0          => 0;
                      :                       :            => 1;
  endrecode;
  if vcheckx then
    vdvalid = 1;
  endif;
end;

{ --------------------------------------------------------------------------- }

{ Check vaccination date is before date of interview }
function vdoi(vcheckd,vcheckm,vchecky);
  { 0 = no problem, 1 = inconsistency: vaccination date after date of interview }
  vdoi = 0;
  { if vac date has valid day, month and year }
  if (vcheckd < 44 and vcheckd > 0) and valid(vcheckm) and vchecky < 9996 then
    { if vac date is after interview date }
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) |
        (cmcode(vcheckm,vchecky) = cmcode(UF8M,UF8Y) and vcheckd > UF8D) then
      vdoi = 1;
    endif;
  { else if vac date has valid month and year only }
  elseif valid(vcheckm) and vchecky < 9996 then
    { if vac date is after interview date }
    if (cmcode(vcheckm,vchecky) > cmcode(UF8M,UF8Y)) then
      vdoi = 1;
    endif;
  { else if vac date has valid year only }
  elseif vchecky < 9996 then
    { if vac date is after interview date }
    if vchecky > UF8Y then
      vdoi = 1;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }

{ Check vaccination date is after date of birth }
function vdob(vcheckd,vcheckm,vchecky);
  { 0 = no problem, 1 = inconsistency: vaccination date before date of birth }
  vdob = 0;
  { if date of birth has valid day, month and year }
  if valid(UF10D) and valid(UF10M) and UF10Y < 9996 then
    { if vac date has valid day, month and year }
    if vcheckd < 44 and valid(vcheckm) and vchecky < 9996 then
      if cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) | (cmcode(vcheckm,vchecky) = cmcode(UF10M,UF10Y) and vcheckd < UF10D) then
        vdob = 1;
      endif;
    { else if vac date has valid month and year only }
    elseif valid(vcheckm) and vchecky < 9996 then
      if cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) then
        vdob = 1;
      endif;
    { else if vac date has valid year only }
    elseif vchecky < 9996 then
      if vchecky < UF10Y then
        vdob = 1;
      endif;
    endif;
  { else if date of birth has valid month and year only }
  elseif valid(UF10M) and UF10Y < 9996 then
    { if vac date has valid month and year only }
    if valid(vcheckm) and vchecky < 9996 then
      if cmcode(vcheckm,vchecky) < cmcode(UF10M,UF10Y) then
        vdob = 1;
      endif;
    { else if vac date has valid year only }
    elseif vchecky < 9996 then
      if vchecky < UF10Y then
        vdob = 1;
      endif;
    endif;
  { if date of birth has valid year only }
  elseif UF10Y < 9996 then
    { if vac date has valid year only }
    if vchecky < 9996 then
      if vchecky < UF10Y then
        vdob = 1;
      endif;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }

{ Check vaccination 1 (e.g., Polio 2) was given before vaccination 2 (e.g., Polio 3) }
function vseq(vcheckd1,vcheckm1,vchecky1,vcheckd2,vcheckm2,vchecky2);
  { 0 = no problem, 1 = inconsistency: vaccination 1's date before vaccination 2's date }
  vseq = 0;
  { if vac 1's date has valid day, month and year }
  if vcheckd1 < 44 and vcheckd1 <> 0 and valid(vcheckm1) and vchecky1 < 9996 then
    { if vac 2's date has valid day, month and year }
    if vcheckd2 < 44 and vcheckd2 <> 0 and valid(vcheckm2) and vchecky2 < 9996 then
      if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) |
        (cmcode(vcheckm2,vchecky2) = cmcode(vcheckm1,vchecky1) and vcheckd2 < vcheckd1) then
        vseq = 1;
      endif;
    { else if vac 2's date has valid month and year only }
    elseif valid(vcheckm2) and vchecky2 < 9996 then
      if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) then
        vseq = 1;
      endif;
    { else if vac 2's date has valid year only }
    elseif vchecky2 < 9996 then
      if vchecky2 < vchecky1 then
        vseq = 1;
      endif;
    endif;
  { else if vac 1's date has valid month and year only }
  elseif valid(vcheckm1) and vchecky1 < 9996 then
    { if vac 2's date has valid month and year only }
    if valid(vcheckm2) and vchecky2 < 9996 then
      if cmcode(vcheckm2,vchecky2) < cmcode(vcheckm1,vchecky1) then
        vseq = 1;
      endif;
    { else if vac 2's date has valid year only }
    elseif vchecky2 < 9996 then
      if vchecky2 < vchecky1 then
        vseq = 1;
      endif;
    endif;
  { else if vac 1's date has valid year only }
  elseif vchecky1 < 9996 then
    { if vac 2's date has valid year only }
    if vchecky2 < 9996 then
      if vchecky2 < vchecky1 then
        vseq = 1;
      endif;
    endif;
  endif;
end;

{ --------------------------------------------------------------------------- }

{ Check two vaccinations are given on the same date, e.g. Polio 1 and DPT 1 }
function vmatch(vcheckd1,vcheckm1,vchecky1,vcheckd2,vcheckm2,vchecky2);
  { 0 = no problem, 1 = inconsistency: vaccinations given on different dates }
  vmatch = 0;
  { if day, month or year of vaccinations are different }
  if vcheckd1 <> vcheckd2 or vcheckm1 <> vcheckm2 or vchecky1 <> vchecky2 then
    vmatch = 1;
  endif;
end;

{ --------------------------------------------------------------------------- }


PROC MICS3_FF
preproc
maxmem = 50;      { maximum number of household members }
maxovc = 50;      { maximum number of OVCs }
hhnum  = 0;       { last household number used }
minage = 15;      { minimum age of eligible women }
maxage = 49;      { maximum age of eligible women }
minab  = 144;     { minimum age at birth in months = 12 years }
minam  = 48;      { minimum age at first marriage = 4 years }
chhlth = 1;       { maximum age at which child is included in child health module - excludes exact age 5 }
chlabl = 5;       { minimum age at which child is included in child labor module - includes exact age 5 }
chlabu = 14;      { maximum age at which child is included in child labor module - excludes exact age 15 }
mindi = 20060101; { replace "20050401" with earliest interview date in yyyymmdd format }

{ frstrun equals 1 if this is the first run for this cluster, 0 otherwise }
frstrun=tonumber(sysparm());
display("Primera corrida = %d",frstrun);

PROC HH
{ *** Level 1 *** }

{ HOUSEHOLD QUESTIONNAIRE }

{ HOUSEHOLD INFORMATION PANEL }

{ Check HH date of interview is valid }
recode HH5Y  :     HH5M        : HH5D => err;
        2006 : 1,3,5,7         : 1-31 => 0;
        2006 : 4,6,            : 1-30 => 0;
        2006 : 2               : 1-28 => 0;
             :                 :      => 1;
endrecode;
if err then
  errmsg(0016,"Del Hogar",HH5D,HH5M,HH5Y);
endif;
dd = (HH5Y*100 + HH5M)*100 + HH5D;
ss = sysdate("yyyymmdd");
if dd >= ss or dd < mindi then
  errmsg(0016,"Del Hogar",HH5D,HH5M,HH5Y);
endif;
di = cmcode(HH5M,HH5Y);

{ Check region agrees with cluster number }
recode HH1  : HH6 => err;   {We modified this for cuban's areas!! }
    001-019 :  1  => 0;
    020-031 :  2  => 0;
    032-032 : 1,2 => 0;
    033-055 :  1  => 0;
    056-063 :  2  => 0;
    064-064 : 1,2 => 0;
    065-184 :  1  => 0;
    185-189 :  2  => 0;
    190-193 : 1,2 => 0;
    194-202 :  1  => 0;
    203-203 :  2  => 0;
    204-205 :  1  => 0;
    206-206 :  2  => 0;
    207-219 :  1  => 0;
    220-224 :  2  => 0;
    225-226 :  1  => 0;
    227-230 :  2  => 0;
    231-244 :  1  => 0;
    245-249 :  2  => 0;
    250-250 :  1  => 0;
    251-251 :  2  => 0;
    252-252 :  1  => 0;
    253-253 :  2  => 0;
    254-255 :  1  => 0;
    256-256 :  2  => 0;
    257-258 :  1  => 0;
    259-259 :  2  => 0;
    260-260 :  1  => 0;
    261-261 :  2  => 0;
    262-263 :  1  => 0;
    264-264 : 1,2 => 0;
    265-268 :  1  => 0;
    269-269 :  2  => 0;
    270-282 :  1  => 0;
    283-287 :  2  => 0;
    288-313 :  1  => 0;
    314-322 :  2  => 0;
    323-336 :  1  => 0;
    337-345 :  2  => 0;
    346-372 :  1  => 0;
    373-391 :  2  => 0;
    392-411 :  1  => 0;
    412-427 :  2  => 0;
    428-428 : 1,2 => 0;
    429-459 :  1  => 0;
    460-476 :  2  => 0;
    477-486 :  1  => 0;
    487-487 :  2  => 0;
    488-488 :  1  => 0;
    489-489 :  2  => 0;
    490-490 :  1  => 0;
    491-492 :  2  => 0;
    493-493 :  1  => 0;
    494-495 :  2  => 0;
    496-496 :  1  => 0;
    497-497 :  2  => 0;
    498-500 :  1  => 0;
    501-501 :  2  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011,HH1,"HH6",HH6);
endif;

{ Check region agrees with cluster number }
recode HH1  : HH7 => err;  {We modified this for cuban's clusters!! }
    001-064 :  1  => 0;
    065-163 :  2  => 0;
    164-193 :  1  => 0;
    194-322 :  3  => 0;
    323-497 :  4  => 0;
    498-501 :  1  => 0;
            :     => 1;
endrecode;
if err then
  errmsg(0011,HH1,"HH7",HH7);
endif;

{ IF HOUSEHOLD INTERVIEW COMPLETE }
if HH9 = 1 then

  { Check not more eligible women than HH members }
  if HH12 > HH11 then
    errmsg(0015,HH12,HH14,HH11);
  endif;

  { Check not more interviews than eligible women }
  if HH13 > HH12 then
    errmsg(0014,HH13,HH12);
  endif;

  { Check not more women and under-5s than HH members }
  if HH12+HH14 > HH11 then
    errmsg(0015,HH12,HH14,HH11);
  endif;

  { Check not more interviews than eligible children }
  if HH15 > HH14 then
    errmsg(0013,HH15,HH14);
  endif;

  { HOUSEHOLD LISTING }

  i = 1;
  while i <= noccurs(MODHL_EDT) do {loop through the household members }
    { Head of household must be on first line }
    if frstrun then
      {if (HL3(i) = 1) <=> (HL1(i) <> 1) then
        errmsg(0141,i,HL3(i));
      endif;}
    endif;

    { Kinship Checks }

    { Check eligible women listed as eligible }
    if HL4(i) = 2 and HL5(i) in minage:maxage then
      if HL6(i) <> HL1(i) then
        errmsg(0101,i,HL4(i),HL5(i),HL6(i));
      endif;
    else
      if HL6(i) <> 0 then
        errmsg(0102,i,HL4(i),HL5(i));
      endif;
    endif;

    { Check child labor eligibility correct }

    { Check eligible children listed as eligible }
    if HL5(i) <= chhlth then
      if HL8(i) = 0 or HL8(i) = HL1(i) then
        errmsg(0131,i,HL4(i),HL5(i),HL8(i));
      elseif HL8(i) > HH11 then
        errmsg(0130,i,HL8(i),HH11);
      endif;
    else
      if HL8(i) <> 0 then
        errmsg(0132,i,HL4(i),HL5(i),HL8(i));
      endif;
    endif;

    { Check that HH member identified by HL10 could be child's mother }

    { Check that relationship code to mother consistent }

    { For Son/Daughter/Head/Spouse/Grandchild/Sibling, try to find (potential) mother's line number, compare it to HL10 }

    { Check that relationship code to father consistent }

    { For Son/Daughter/Head/Spouse/Grandchild/Sibling, try to find (potential) father's line number, compare it to HL12 }

    i = i + 1
  enddo;

  { Compare household count variables to recounts of household members }
  cnt = count(MODHL_EDT where HL6 > 0);
  if TOHL6 <> cnt then
    errmsg(0110,"Mujeres 15-49","T0HL6",TOHL6,cnt);
  elseif TOHL6 <> HH12 then
    errmsg(0111,"Mujeres 15-49",TOHL6,"HH12",HH12);
  endif;


  cnt = count(MODHL_EDT where HL8 > 0);
  if TOHL8 <> count(MODHL_EDT where HL8 > 0) then
    errmsg(0110,"Bajo 5","T0HL8",TOHL8,cnt);
  elseif TOHL8 <> HH14 then
    errmsg(0111,"Bajo 5",TOHL8,"HH14",HH14);
  endif;


  { EDUCATION MODULE }

  i = 1;
  while i <= noccurs(MODHL_EDT) do {loop through the education module }

    { Check consistency of highest level and grade }
    if ED3A(i) <> notappl then
      lev = ED3A(i);
      grd = ED3B(i);
      recode lev  : grd         => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          0 : 0-0         => 0;   { preescolar}
          1 : 0-6         => 0;   { Primaria }
          2 : 0-3         => 0;   { Secundaria }
          3 : 0-5         => 0;   { Obrero }
          4 : 0-5 	  => 0;   { PreUniv/Tc }
          5 : 0-7 	  => 0;   { Superior}
          8 :             => 0;   { no sabe }
          9 :             => 0;   { Missing level }
            :             => 1;
      endrecode;
      if err then
        errmsg(0090,i,"ED3A",lev,"ED3B",grd);
      endif;
    endif;

    { Check current level not higher than highest level }
    
    { Check consistency of current level and grade }
  
    { Check current grade not higher than highest grade }
    
    { Check previous year's level not higher than highest level }
    
    { Check consistency of highest level and grade }
   
    { Check previous year's grade not higher than highest grade }

    i = i + 1
  enddo;
   
  { WATER AND SANITATION MODULE }

  { Check WS3's value divisible by 0 or 5 }
  if frstrun and WS3 < 995 and WS3%10 <> 0 and WS3%10 <> 5 then
    errmsg(9993,"WS3",WS3);
  endif;

  { ITN MODULE }

  
  { CHILD LABOR MODULE }


  { CHILD DISCIPLINE MODULE }


  { MATERNAL MORTALITY MODULE }
 { END HOUSEHOLD INTERVIEW COMPLETE }
endif;

PROC WMCH
{ *** Level 2 *** }

{ WOMEN'S QUESTIONNAIRE }

{ WOMEN'S INFORMATION PANEL }

{ Check date of interview }
if WM6D <> notappl then
  recode WM6Y   :     WM6M        : WM6D => err;
      2005-2006 : 1,3,5,7,8,10,12 : 1-31 => 0;
      2005-2006 : 4,6,9,11        : 1-30 => 0;
      2005-2006 : 2               : 1-28 => 0;
                :                 :      => 1;
  endrecode;
  if err then
    errmsg(0016,"De la Mujer",WM6D,WM6M,WM6Y);
  endif;
  dd = (HH5Y*100 + HH5M)*100 + HH5D;
  ddw= (WM6Y*100 + WM6M)*100 + WM6D;
  ss = sysdate("yyyymmdd");
  if ddw >= ss or ddw < dd then
    errmsg(0016,"De la Mujer",WM6D,WM6M,WM6Y);
  endif;
  diwm = cmcode(WM6M,WM6Y);
endif;

{ IF WOMEN'S INTERVIEW COMPLETE }
if WM7 = 1 then

  { Check date of birth against date of interview }
  udob = diwm - minage*12;
  ldob = diwm - maxage*12 - 11;
  if WM8Y < 9997 then
    ldob = setlb(WM8M,WM8Y,0);
    udob = setub(WM8M,WM8Y,9999);
    if udob < diwm - maxage*12 - 11 or ldob > diwm - minage*12 then
      if (WM6M = WM8M) and (WM8Y - 50 = WM6Y) then
        if frstrun then
          errmsg(1001,WM6M,WM6Y,WM8M,WM8Y);
        endif;
      else
        errmsg(1001,WM6M,WM6Y,WM8M,WM8Y);
      endif;
    endif;
  endif;

  { Check age against age in household }
  if frstrun and WM9 <> HL5(WM4) then
    errmsg(1002,WM9,HL5(LN));
  endif;

  { Check age, date of birth and date of interview }
  { Lower bound of CMC date of birth }
  t = adjlba(ldob,udob,diwm,diwm,WM9);
  if t < 0 then
    if (WM6M = WM8M) and (WM8Y - WM6Y = WM9 + 1) then
      if frstrun then
        errmsg(1003,WM9,WM8M,WM8Y,WM6M,WM6Y);
      endif;
    else
      errmsg(1003,WM9,WM8M,WM8Y,WM6M,WM6Y);
    endif;
  else
    ldob = t
  endif;
  { Upper bound of CMC date of birth }
  t = adjuba(ldob,udob,diwm,diwm,WM9);
  if t < 0 then
    if (WM6M = WM8M) and (WM8Y - WM6Y = WM9 + 1) then
      if frstrun then
        errmsg(1003,WM9,WM8M,WM8Y,WM6M,WM6Y);
      endif;
    else
      errmsg(1003,WM9,WM8M,WM8Y,WM6M,WM6Y);
    endif;
  else
    udob = t
  endif;

  if frstrun then
    { Check school attendance against value in household }
    if WM10 <> ED2(LN) and ED3(LN) <> 0 then
      errmsg(1011,ED2(LN),WM10);
    endif;

    { If ever attended school }
    if WM10 = 1 then
      { Check highest level against value in household }
      if WM11 <> ED3A(LN) then
        errmsg(1012,ED3A(LN),WM11);
      endif;

      { Check highest grade against value in household }
      if WM12 <> ED3B(LN) then
        errmsg(1013,ED3B(LN),WM12);
      endif;
    endif;
  endif;

  { If ever attended school }
  if WM10 = 1 then
    { Check highest level and grade consistent }
    lev = WM11;
    grd = WM12;
    recode lev  : grd     => err; { Fix maximum grade for each possible level }
            : 97,98,99    => 0;   { Inconsistent, missing, DK grade }
          0 : 0-1	  => 0;   {Preescolar }
          1 : 0-6         => 0;   { Primary }
          2 : 0-3         => 0;   { Secondary }
          3 : 0-5         => 0;   { Obrero }
          4 : 0-5	  => 0;   {Preuniv}
          5 : 0-7         => 0;   { Superior }
          8 :             => 0;   { DK level }
          9 :             => 0;   { Missing level }
            :             => 1;
    endrecode;
    if err then
      errmsg(1014,WM11,WM12);
    endif;
  endif;

  { CHILD MORTALITY MODULE }

  

  { TETANUS TOXOID MODULE }


  { MATERNAL AND NEWBORN HEALTH MODULE }

  { Check special answers }
  

  { Check consistency between units and numbers }
  if BF1 = 1 then
    recode MN13U  : MN13N       => err;
              0   : 0           => 0;   { Immediately }
              1   : 0-23        => 0;   { Hours }
              2   : 1-90        => 0;   { Days }
              9   : 98-99       => 0;   { DK, Missing }
                  :             => 1;
    endrecode;
    if err then
      errmsg(9992,"MN13U",MN13U,"MN13N",MN13N);
    endif;
  endif;

  { MARRIAGE/UNION MODULE }

  { CONTRACEPTION MODULE }

  { Check units and number consistent }
  if CP4A = 1 then
    recode CP4CU  : CP4CN       => err;
              1,2 : 0-90        => 0;   { Months, Years }
              9   : 93-96,98,99 => 0;   { Special, DK, Missing }
                  :             => 1;
    endrecode;
    if err then
      errmsg(9992,"CP4CU",CP4CU,"CP4CN",CP4CN);
    endif;
  endif;

  { FEMALE GENITAL CUTTING MODULE }


  { SEXUAL BEHAVIOUR MODULE }

endif;


{ CHILDREN'S QUESTIONNAIRE }

{ UNDER-FIVE CHILD INFORMATION PANEL }

{ Check caretaker's line number against value in household}
if UF6 <> notappl and HL8(LN) <> UF6 then
  errmsg(2004,UF6,LN,HL8(LN));
endif;

{ Check date of interview consistent }
if UF8D <> notappl then
  recode  UF8Y  :     UF8M        : UF8D => err;
           2006 : 1,3,5,7         : 1-31 => 0;
           2006 : 4,6             : 1-30 => 0;
           2006 : 2               : 1-28 => 0;
                :                 :      => 1;
  endrecode;
  if err then
    errmsg(0016,"Del Nio",UF8D,UF8M,UF8Y);
  endif;
  dd = (HH5Y*100 + HH5M)*100 + HH5D;
  ddw= (UF8Y*100 + UF8M)*100 + UF8D;
  ss = sysdate("yyyymmdd");
  if ddw >= ss or ddw < dd then
    errmsg(0016,"Del Nio",UF8D,UF8M,UF8Y);
  endif;
  dich = cmcode(UF8M,UF8Y);
endif;

{ IF CHILD'S INTERVIEW COMPLETE }
if UF9 = 1 then

  { Check date of birth consistent with date of interview }
  udob = dich;
  ldob = dich - chhlth*12 - 11;
  if UF10Y < 9997 then
    ldob = setlb(UF10M,UF10Y,0);
    udob = setub(UF10M,UF10Y,9999);
    if udob < dich - chhlth*12 - 11 or ldob > dich then
      if (UF8M = UF10M) and (UF8Y - 5 = UF10Y) then
        { Do nothing if DOB valid given day }
        if valid(UF10d) and UF8D <= UF10D then
        { Error if DOB invalid given day }
        elseif valid(UF8D) and UF8D > UF10D then
          errmsg(2001,UF10M,UF10Y,UF8M,UF8Y);
        { If impossible to verify DOB since UF8D invalid, warn on first run }
        elseif !valid(UF8D) and frstrun then
          errmsg(2001,UF10M,UF10Y,UF8M,UF8Y);
        endif;
      else
        errmsg(2001,UF10M,UF10Y,UF8M,UF8Y);
      endif;
    endif;
  endif;

  { Check age consistent with value in household }
  if frstrun and UF11 <> HL5(UF4) then
    errmsg(2002,UF11,HL5(LN));
  endif;

  { Check age, date of birth and date of interview consistent }
  { If day, month and year of birth are valid }
  if valid(UF10D) and valid(UF10M) and UF10Y < 9997 then
    if (UF10M = UF8M and UF10D > UF8D) | (UF10M > UF8M) then
      age = UF8Y - UF10Y - 1;
    else
      age = UF8Y - UF10Y;
    endif;
    if age <> UF11 then
      errmsg(2003,UF11,UF10D,UF10M,UF10Y,UF8D,UF8M,UF8Y);
    endif;
  else
    { Lower bound of CMC date of birth }
    t = adjlba(ldob,udob,dich,dich,UF11);
    if t < 0 then
      if (UF8M = UF10M) and (UF8Y - 5 = UF10Y) then
        if frstrun then
          errmsg(2003,UF11,UF10D,UF10M,UF10Y,UF8D,UF8M,UF8Y);
        endif;
      else
        errmsg(2003,UF11,UF10D,UF10M,UF10Y,UF8D,UF8M,UF8Y);
      endif;
    else
      ldob = t
    endif;
    { Upper bound of CMC date of birth }
    t = adjuba(ldob,udob,dich,dich,UF11);
    if t < 0 then
      if (UF8M = UF10M) and (UF8Y - 5 = UF10Y) then
        if frstrun then
          errmsg(2003,UF11,UF10D,UF10M,UF10Y,UF8D,UF8M,UF8Y);
        endif;
      else
        errmsg(2003,UF11,UF10D,UF10M,UF10Y,UF8D,UF8M,UF8Y);
      endif;
    else
      udob = t
    endif;
  endif;

  { VITAMIN A MODULE }
  { CARE OF ILLNESS MODULE }
  { MALARIA MODULE FOR UNDER-FIVES }

  { IMMUNIZATION MODULE }

  if IM1 = 1 then
       { Check BCG }
       if vdvalid(IM2D,IM2M,IM2Y) then
         errmsg(2701,"BCG",IM2D,IM2M,IM2Y);
       elseif vdoi(IM2D,IM2M,IM2Y) then
         errmsg(2702,"BCG",IM2D,IM2M,IM2Y,UF8D,UF8M,UF8Y);
       elseif vdob(IM2D,IM2M,IM2Y) then
         errmsg(2703,"BCG",IM2D,IM2M,IM2Y,UF10D,UF10M,UF10Y);
       endif;

        { Check Hepatitis B* 12 a 24 horas }
        if vdvalid(IM3A1D,IM3A1M,IM3A1Y) then
	  errmsg(2701,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y);
	elseif vdoi(IM3A1D,IM3A1M,IM3A1Y) then
	  errmsg(2702,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3A1D,IM3A1M,IM3A1Y) then
	  errmsg(2703,"Hepatitis B Viral(*)12-24 Horas",IM3A1D,IM3A1M,IM3A1Y,UF10D,UF10M,UF10Y);
	endif;


        { Check Hepatitis B* 1 mes }
	if vdvalid(IM3B1D,IM3B1M,IM3B1Y) then
	  errmsg(2701,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y);
	elseif vdoi(IM3B1D,IM3B1M,IM3B1Y) then
	  errmsg(2702,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3B1D,IM3B1M,IM3B1Y) then
	  errmsg(2703,"Hepatitis B Viral(*)1 Mes",IM3B1D,IM3B1M,IM3B1Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hepatitis B* 2 meses }
	if vdvalid(IM3C1D,IM3C1M,IM3C1Y) then
	  errmsg(2701,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y);
	elseif vdoi(IM3C1D,IM3C1M,IM3C1Y) then
	  errmsg(2702,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3C1D,IM3C1M,IM3C1Y) then
	  errmsg(2703,"Hepatitis B Viral(*)2 Meses",IM3C1D,IM3C1M,IM3C1Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hepatitis B* 12 meses }
	if vdvalid(IM3D1D,IM3D1M,IM3D1Y) then
	  errmsg(2701,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y);
	elseif vdoi(IM3D1D,IM3D1M,IM3D1Y) then
	  errmsg(2702,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3D1D,IM3D1M,IM3D1Y) then
	  errmsg(2703,"Hepatitis B Viral(**)12 meses",IM3D1D,IM3D1M,IM3D1Y,UF10D,UF10M,UF10Y);
	endif;

	 { Check Hepatitis B** 12 a 24 horas }
	if vdvalid(IM3A2D,IM3A2M,IM3A2Y) then
	  errmsg(2701,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y);
	elseif vdoi(IM3A2D,IM3A2M,IM3A2Y) then
	  errmsg(2702,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3A2D,IM3A2M,IM3A2Y) then
	  errmsg(2703,"Hepatitis B Viral(**)12-24 Horas",IM3A2D,IM3A2M,IM3A2Y,UF10D,UF10M,UF10Y);
	endif;

  {if IM0 = 1 then  (Esquema 1) }
  
	 { Check Hepatitis B** 1 mes }
	if vdvalid(IM3B2D,IM3B2M,IM3B2Y) then
	  errmsg(2701,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y);
	elseif vdoi(IM3B2D,IM3B2M,IM3B2Y) then
	  errmsg(2702,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3B2D,IM3B2M,IM3B2Y) then
	  errmsg(2703,"Hepatitis B Viral(**)1 Mes",IM3B2D,IM3B2M,IM3B2Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hepatitis B** 6 mes }
	if vdvalid(IM3C2D,IM3C2M,IM3C2Y) then
	  errmsg(2701,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y);
	elseif vdoi(IM3C2D,IM3C2M,IM3C2Y) then
	  errmsg(2702,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM3C2D,IM3C2M,IM3C2Y) then
	  errmsg(2703,"Hepatitis B Viral(**)6 Meses",IM3C2D,IM3C2M,IM3C2Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check DPT 2 Meses }
	if vdvalid(IM4A1D,IM4A1M,IM4A1Y) then
	  errmsg(2701,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y);
	elseif vdoi(IM4A1D,IM4A1M,IM4A1Y) then
	  errmsg(2702,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4A1D,IM4A1M,IM4A1Y) then
	  errmsg(2703,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check DPT 4 Meses }
	if vdvalid(IM4B1D,IM4B1M,IM4B1Y) then
	  errmsg(2701,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y);
	elseif vdoi(IM4B1D,IM4B1M,IM4B1Y) then
	  errmsg(2702,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4B1D,IM4B1M,IM4B1Y) then
	  errmsg(2703,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check DPT 6 Meses }
	if vdvalid(IM4C1D,IM4C1M,IM4C1Y) then
	  errmsg(2701,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y);
	elseif vdoi(IM4C1D,IM4C1M,IM4C1Y) then
	  errmsg(2702,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4C1D,IM4C1M,IM4C1Y) then
	  errmsg(2703,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y,UF10D,UF10M,UF10Y);
	endif;
	
  {endif;  (Esquema 1) }

  {if IM0 = 2 then  (Esquema 2) }

	{ Check DPT + HB(**) 2 Meses }
	if vdvalid(IM4A2D,IM4A2M,IM4A2Y) then
	  errmsg(2701,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y);
	elseif vdoi(IM4A2D,IM4A2M,IM4A2Y) then
	  errmsg(2702,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4A2D,IM4A2M,IM4A2Y) then
	  errmsg(2703,"DPT + HB(**) 2 Meses",IM4A2D,IM4A2M,IM4A2Y,UF10D,UF10M,UF10Y);
	endif;


	{ Check DPT + HB(**) 4 Meses }
	if vdvalid(IM4B2D,IM4B2M,IM4B2Y) then
	  errmsg(2701,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y);
	elseif vdoi(IM4B2D,IM4B2M,IM4B2Y) then
	  errmsg(2702,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4B2D,IM4B2M,IM4B2Y) then
	  errmsg(2703,"DPT + HB(**) 4 Meses",IM4B2D,IM4B2M,IM4B2Y,UF10D,UF10M,UF10Y);
	endif;


	{ Check DPT + HB(**) 6 Meses }
	if vdvalid(IM4C2D,IM4C2M,IM4C2Y) then
	  errmsg(2701,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y);
	elseif vdoi(IM4C2D,IM4C2M,IM4C2Y) then
	  errmsg(2702,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM4C2D,IM4C2M,IM4C2Y) then
	  errmsg(2703,"DPT + HB(**) 6 Meses",IM4C2D,IM4C2M,IM4C2Y,UF10D,UF10M,UF10Y);
	endif;

  {endif;   (Esquema 2) }

	{ Check DPT 15-18 Meses }
	if vdvalid(IM4DD,IM4DM,IM4DY) then
	  errmsg(2701,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY);
	elseif vdoi(IM4DD,IM4DM,IM4DY) then
	  errmsg(2702,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY,UF8D,UF8M,UF8Y);
	elseif vdob(IM4DD,IM4DM,IM4DY) then
	  errmsg(2703,"DPT 15 o 18 Meses",IM4DD,IM4DM,IM4DY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hib 2 Meses }
	if vdvalid(IM5AD,IM5AM,IM5AY) then
	  errmsg(2701,"Hib 2 meses",IM5AD,IM5AM,IM5AY);
	elseif vdoi(IM5AD,IM5AM,IM5AY) then
	  errmsg(2702,"Hib 2 meses",IM5AD,IM5AM,IM5AY,UF8D,UF8M,UF8Y);
	elseif vdob(IM5AD,IM5AM,IM5AY) then
	  errmsg(2703,"Hib 2 meses",IM5AD,IM5AM,IM5AY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hib 4 Meses }
	if vdvalid(IM5BD,IM5BM,IM5BY) then
	  errmsg(2701,"Hib 4 Meses",IM5BD,IM5BM,IM5BY);
	elseif vdoi(IM5BD,IM5BM,IM5BY) then
	  errmsg(2702,"Hib 4 Meses",IM5BD,IM5BM,IM5BY,UF8D,UF8M,UF8Y);
	elseif vdob(IM5BD,IM5BM,IM5BY) then
	  errmsg(2703,"Hib 4 Meses",IM5BD,IM5BM,IM5BY,UF10D,UF10M,UF10Y);
	endif;


	{ Check Hib 6 Meses }
	if vdvalid(IM5CD,IM5CM,IM5CY) then
	  errmsg(2701,"Hib 6 Meses",IM5CD,IM5CM,IM5CY);
	elseif vdoi(IM5CD,IM5CM,IM5CY) then
	  errmsg(2702,"Hib 6 Meses",IM5CD,IM5CM,IM5CY,UF8D,UF8M,UF8Y);
	elseif vdob(IM5CD,IM5CM,IM5CY) then
	  errmsg(2703,"Hib 6 Meses",IM5CD,IM5CM,IM5CY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Hib 15 o 18 Meses }
	if vdvalid(IM5DD,IM5DM,IM5DY) then
	  errmsg(2701,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY);
	elseif vdoi(IM5DD,IM5DM,IM5DY) then
	  errmsg(2702,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY,UF8D,UF8M,UF8Y);
	elseif vdob(IM5DD,IM5DM,IM5DY) then
	  errmsg(2703,"Hib 15 o 18 Meses",IM5DD,IM5DM,IM5DY,UF10D,UF10M,UF10Y);
	endif;

	{ Check AM-BC 3 Meses }
	if vdvalid(IM6AD,IM6AM,IM6AY) then
	  errmsg(2701,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY);
	elseif vdoi(IM6AD,IM6AM,IM6AY) then
	  errmsg(2702,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY,UF8D,UF8M,UF8Y);
	elseif vdob(IM6AD,IM6AM,IM6AY) then
	  errmsg(2703,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY,UF10D,UF10M,UF10Y);
	endif;


	{ Check AM-BC 5 Meses }
	if vdvalid(IM6BD,IM6BM,IM6BY) then
	  errmsg(2701,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY);
	elseif vdoi(IM6BD,IM6BM,IM6BY) then
	  errmsg(2702,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY,UF8D,UF8M,UF8Y);
	elseif vdob(IM6BD,IM6BM,IM6BY) then
	  errmsg(2703,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY,UF10D,UF10M,UF10Y);
	endif;

	{ Check PRS }
	if vdvalid(IM7D,IM7M,IM7Y) then
	  errmsg(2701,"PRS",IM7D,IM7M,IM7Y);
	elseif vdoi(IM7D,IM7M,IM7Y) then
	  errmsg(2702,"PRS",IM7D,IM7M,IM7Y,UF8D,UF8M,UF8Y);
	elseif vdob(IM7D,IM7M,IM7Y) then
	  errmsg(2703,"PRS",IM7D,IM7M,IM7Y,UF10D,UF10M,UF10Y);
	endif;

	{ Check Polio menor 1 dosis 1 }
	if vdvalid(IM8AD,IM8AM,IM8AY) then
	  errmsg(2701,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY);
	elseif vdoi(IM8AD,IM8AM,IM8AY) then
	  errmsg(2702,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8AD,IM8AM,IM8AY) then
	  errmsg(2703,"Polio menor 1 dosis 1",IM8AD,IM8AM,IM8AY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Polio menor 1 dosis 2 }
	if vdvalid(IM8BD,IM8BM,IM8BY) then
	  errmsg(2701,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY);
	elseif vdoi(IM8BD,IM8BM,IM8BY) then
	  errmsg(2702,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8BD,IM8BM,IM8BY) then
	  errmsg(2703,"Polio menor 1 dosis 2",IM8BD,IM8BM,IM8BY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Polio 1 dosis 1 }
	if vdvalid(IM8CD,IM8CM,IM8CY) then
	  errmsg(2701,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY);
	elseif vdoi(IM8CD,IM8CM,IM8CY) then
	  errmsg(2702,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8CD,IM8CM,IM8CY) then
	  errmsg(2703,"Polio 1 dosis 1",IM8CD,IM8CM,IM8CY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Polio 1 dosis 2 }
	if vdvalid(IM8DD,IM8DM,IM8DY) then
	  errmsg(2701,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY);
	elseif vdoi(IM8DD,IM8DM,IM8DY) then
	  errmsg(2702,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8DD,IM8DM,IM8DY) then
	  errmsg(2703,"Polio 1 dosis 2",IM8DD,IM8DM,IM8DY,UF10D,UF10M,UF10Y);
	endif;

	{ Check Polio 2 dosis 1 }
	{if vdvalid(IM8ED,IM8EM,IM8EY) then
	  errmsg(2701,"Polio 2 dosis 1",IM8ED,IM8EM,IM8EY);
	elseif vdoi(IM8ED,IM8EM,IM8EY) then
	  errmsg(2702,"Polio 2 dosis 1",IM8ED,IM8EM,IM8EY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8ED,IM8EM,IM8EY) then
	  errmsg(2703,"Polio 2 dosis 1",IM8ED,IM8EM,IM8EY,UF10D,UF10M,UF10Y);
	endif;}

	{ Check Polio 2 dosis 2}
	{if vdvalid(IM8FD,IM8FM,IM8FY) then
	  errmsg(2701,"Polio 2 dosis 2",IM8FD,IM8FM,IM8FY);
	elseif vdoi(IM8FD,IM8FM,IM8FY) then
	  errmsg(2702,"Polio 2 dosis 2",IM8FD,IM8FM,IM8FY,UF8D,UF8M,UF8Y);
	elseif vdob(IM8FD,IM8FM,IM8FY) then
	  errmsg(2703,"Polio 2 dosis 2",IM8FD,IM8FM,IM8FY,UF10D,UF10M,UF10Y);
	endif;}

	
	{--------------Check if date of 2nd dose is consistent with first one------}
    { Check All HB(*) }
    if vseq(IM3A1D,IM3A1M,IM3A1Y,IM3B1D,IM3B1M,IM3B1Y) then
      errmsg(2704,"HB(*) 12-24 Horas",IM3A1D,IM3A1M,IM3A1Y,"HB(*) 1 Mes",IM3B1D,IM3B1M,IM3B1Y);
    endif;
    if vseq(IM3B1D,IM3B1M,IM3B1Y,IM3C1D,IM3C1M,IM3C1Y) then
      errmsg(2704,"HB(*) 1 Mes",IM3B1D,IM3B1M,IM3B1Y,"HB(*) 2 Meses",IM3C1D,IM3C1M,IM3C1Y);
    endif;
    if vseq(IM3C1D,IM3C1M,IM3C1Y,IM3D1D,IM3D1M,IM3D1Y) then
      errmsg(2704,"HB(*) 2 Meses",IM3C1D,IM3C1M,IM3C1Y,"HB(*) 12 Meses",IM3D1D,IM3D1M,IM3D1Y);
    endif;
    if vseq(IM3A2D,IM3A2M,IM3A2Y,IM3B2D,IM3B2M,IM3B2Y) then
      errmsg(2704,"HB(**) 12-24 Horas",IM3A2D,IM3A2M,IM3A2Y,"HB(**) 1 Mes",IM3B2D,IM3B2M,IM3B2Y);
    endif;
    {if IM0 <> 1 then}
      if vseq(IM3B2D,IM3B2M,IM3B2Y,IM3C2D,IM3C2M,IM3C2Y) then
    	  errmsg(2704,"HB(**) 1 Mes",IM3B2D,IM3B2M,IM3B2Y,"HB(**) 6 Meses",IM3C2D,IM3C2M,IM3C2Y);
      endif;
    {endif;}

    { Check All DPT(*) Schema1 }
    if vseq(IM4A1D,IM4A1M,IM4A1Y,IM4B1D,IM4B1M,IM4B1Y) then
      errmsg(2704,"DPT 2 Meses",IM4A1D,IM4A1M,IM4A1Y,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y);
    endif;
    if vseq(IM4B1D,IM4B1M,IM4B1Y,IM4C1D,IM4C1M,IM4C1Y) then
      errmsg(2704,"DPT 4 Meses",IM4B1D,IM4B1M,IM4B1Y,"DPT 6 Meses",IM4C1D,IM4C1M,IM4C1Y);
    endif;

    { Check All DPT(*) + HB(**) Schema2 }
    if vseq(IM4A2D,IM4A2M,IM4A2Y,IM4B2D,IM4B2M,IM4B2Y) then
      errmsg(2704,"DPT + HB 2 Meses",IM4A2D,IM4A2M,IM4A2Y,"DPT + HB 4 Meses",IM4B2D,IM4B2M,IM4B2Y);
    endif;
    if vseq(IM4B2D,IM4B2M,IM4B2Y,IM4C2D,IM4C2M,IM4C2Y) then
      errmsg(2704,"DPT + HB 4 Meses",IM4B2D,IM4B2M,IM4B2Y,"DPT + HB 6 Meses",IM4C2D,IM4C2M,IM4C2Y);
    endif;

    { Check DPT(*) de 15 a 18 Meses}
    if vseq(IM4C1D,IM4C1M,IM4C1Y,IM4DD,IM4DM,IM4DY) then
      errmsg(2704,"DPT + HB 6 Meses",IM4C1D,IM4C1M,IM4C1Y,"DPT de 15 a 18 Meses",IM4DD,IM4DM,IM4DY);
	endif;

    { Check All HIB }
    if vseq(IM5AD,IM5AM,IM5AY,IM5BD,IM5BM,IM5BY) then
      errmsg(2704,"HIB 2 Meses",IM5AD,IM5AM,IM5AY,"HIB 4 Meses",IM5BD,IM5BM,IM5BY);
    endif;
    if vseq(IM5BD,IM5BM,IM5BY,IM5CD,IM5CM,IM5CY) then
      errmsg(2704,"HIB 4 Meses",IM5BD,IM5BM,IM5BY,"HIB 6 Meses",IM5CD,IM5CM,IM5CY);
    endif;
    if vseq(IM5CD,IM5CM,IM5CY,IM5DD,IM5DM,IM5DY) then
      errmsg(2704,"HIB 6 Meses",IM5CD,IM5CM,IM5CY,"HIB 15 o 18 Meses",IM5DD,IM5DM,IM5DY);
    endif;

    { Check All AM-BC }
    if vseq(IM6AD,IM6AM,IM6AY,IM6BD,IM6BM,IM6BY) then
      errmsg(2704,"AM-BC 3 Meses",IM6AD,IM6AM,IM6AY,"AM-BC 5 Meses",IM6BD,IM6BM,IM6BY);
    endif;

    { Check All Polios}
    if vseq(IM8AD,IM8AM,IM8AY,IM8BD,IM8BM,IM8BY) then
      errmsg(2704,"Polio -1 1 Dosis",IM8AD,IM8AM,IM8AY,"Polio -1 2 Dosis",IM8BD,IM8BM,IM8BY);
    endif;
    if vseq(IM8BD,IM8BM,IM8BY,IM8CD,IM8CM,IM8CY) then
      errmsg(2704,"Polio -1 2 Dosis",IM8BD,IM8BM,IM8BY,"Polio 1 1 Dosis",IM8CD,IM8CM,IM8CY);
    endif;
    if vseq(IM8CD,IM8CM,IM8CY,IM8DD,IM8DM,IM8DY) then
      errmsg(2704,"Polio 1 1 Dosis",IM8CD,IM8CM,IM8CY,"Polio 1 2 Dosis",IM8DD,IM8DM,IM8DY);
    endif;
    {if vseq(IM8DD,IM8DM,IM8DY,IM8ED,IM8EM,IM8EY) then
      errmsg(2704,"Polio 1 2 Dosis",IM8DD,IM8DM,IM8DY,"Polio 1 2 Dosis",IM8ED,IM8EM,IM8EY);
    endif;
    if vseq(IM8ED,IM8EM,IM8EY,IM8FD,IM8FM,IM8FY) then
      errmsg(2704,"Polio 1 2 Dosis",IM8ED,IM8EM,IM8EY,"Polio 2 2 Dosis",IM8FD,IM8FM,IM8FY);
    endif;}
    
  endif;

  { Check receipt of vaccinations against recorded vaccinations }
  if frstrun then
    if IM1 = 1 and  (IM2D = 0 and IM3A1D = 0 and IM3B1D = 0 and IM3C1D = 0 and IM3D1D = 0 and
    				IM3A2D = 0 and IM3B2D = 0 and IM3C2D = 0 and 
                    IM4A1D = 0 and IM4B1D = 0 and IM4C1D = 0 and
                    IM4A2D = 0 and IM4B2D = 0 and IM4C2D = 0 and IM4DD = 0 and
                    IM5AD = 0 and IM5BD = 0 and IM5CD = 0 and IM5DD = 0 and
                    IM6AD = 0 and IM6BD = 0 and IM7D = 0 and 
                    IM8AD = 0 and IM8BD = 0 and IM8CD = 0 and IM8DD = 0 ) then
      errmsg(2706);
    endif;
  endif;

  { Check receipt of other vaccinations against recorded vaccinations }
  if frstrun and IM1 = 1 then
    if IM9 = 1 <=> (IM2D <> 66 and IM3A1D <> 66 and IM3B1D <> 66 and IM3C1D <> 66 and IM3D1D <> 66 and
    				IM3A2D <> 66 and IM3B2D <> 66 and IM3C2D <> 66 and 
                    IM4A1D <> 66 and IM4B1D <> 66 and IM4C1D <> 66 and
                    IM4A2D <> 66 and IM4B2D <> 66 and IM4C2D <> 66 and IM4DD <> 66 and
                    IM5AD <> 66 and IM5BD <> 66 and IM5CD <> 66 and IM5DD <> 66 and
                    IM6AD <> 66 and IM6BD <> 66 and IM7D <> 66 and 
                    IM8AD <> 66 and IM8BD <> 66 and IM8CD <> 66 and IM8DD <> 66 ) then
      errmsg(2707);
    endif;
  endif;
  
  { For Cuban's survey, check there's not scheme crossing }
  schema1 = 0;
  schema2 = 0;
  if (IM3B2D > 0 or IM3C2D > 0 or IM4A1D > 0 or IM4B1D > 0 or IM4C1D > 0) and 
	((IM3B2D <> 44 or IM3C2D <> 44 or IM4A1D <> 44 or IM4B1D <> 44 or IM4C1D <> 44) or
	(IM3B2D <> 66 or IM3C2D <> 66 or IM4A1D <> 66 or IM4B1D <> 66 or IM4C1D <> 66)) then
	schema1 = 1;
  endif;
  if (IM4A2D > 0 or IM4B2D > 0 or IM4C2D > 0) and 
	((IM4A2D <> 44 or IM4B2D <> 44 or IM4C2D <> 44) or
	(IM4A2D <> 66 or IM4B2D <> 66 or IM4C2D <> 66)) then
	schema2 = 1;
  endif;
  if (schema1 + schema2 > 1) then
  	errmsg(2708);
  endif;

  { ANTHROPOMETRY MODULE }

endif; { END CHILD'S INTERVIEW COMPLETE }
