PROC GLOBAL
set explicit;
{ Working variables -- check the lengths needed for all fields }
alpha(40) CSPro;                                                { CSPro executables directory }
alpha(26)  proj;                                                { project directory name }
alpha(8)  cmapp, deapp, edapp, exapp,
          gpapp, scapp, dic;                    { application names and dictionary name }
alpha(16) clusterapp;
alpha(20) printapp;
alpha(8)  opid;                                                 { operator ID }
alpha(30)  floppy;                                              { !!! TRANSFER !!! make sure length of variable to store transfer drive is long enough }
alpha(2)  wrkdrv;                                               { length of var to store workdrive letters, e.g. "C:" }
alpha(32) wrkprj, backup, expdir, gps,
          final, raw, veri, xdir;       { various directories }
alpha(8)  dicts, entry, super;          { directory names for DICTS, ENTRY, SUPER }
alpha(3)  xcluster;                     { !!! CLUSTER !!! make sure length of cluster number is correct }
alpha(2)  fcodes;                       { file codes - M = Main, V = Verification }
alpha(2)  hcodes;                       { code for household data file name }
alpha(1)  frstrun;                                  { is this the first run of the editing program }

numeric always, choice, chkok, noyes, err, docopy, t;
numeric i, maxclusternumber, startpos, dd, dr, de, ss, valid;

file pfffile mdata vdata wdata datacopy alldata jstone dirname;

{ ---------------------------------------------------------------------------- }

function chkdir()
  setfile(dirname,xdir);
  if fileexist(xdir) <> 1 then
    errmsg("El directorio '%s' no existe",xdir);
    stop(-1);
  endif;
end;

function chkexist(mychoice)
  chkok = 1;
  if mychoice = 4 then { if verifying data }
    { !!! NETWORK !!! change wording of message if using a network }
    errmsg("*** Inserte un diskette con los datos verificados en el drive %s",floppy);
    setfile(vdata,concat(strip(floppy), "\",hcodes, xcluster, "V", ".DAT"));
    if !fileexist(wdata) then { main data doesn't exist in raw directory }
      errmsg("Archivo de datos original del consultorio %s no existe --- use primero la opcin %s",xcluster,"A");
      chkok = 0;
    elseif !fileexist(vdata) then { verification data doesn't exist }
      { !!! NETWORK !!! change wording of message if using a network }
      errmsg("El archivo de datos para Verificacin del consultorio %s no esta en el diskette",xcluster);
      chkok = 0;
    endif;
  elseif mychoice = 5 then { if backing up raw data }
    if !fileexist(wdata) then { main data doesn't exist in raw directory }
      errmsg("El archivo original de datos del consultorio %s no existe",xcluster);
      chkok = 0;
    endif;
  elseif mychoice in 7,8,9 then { if using raw data }
    if !fileexist(wdata) then { raw data doesn't exist }
      errmsg("El archivo original de datos del consultorio %s no existe",xcluster);
      chkok = 0;
    endif;
  endif;
  chkexist = chkok;
end;

function genpff(mychoice)
  if mychoice = 3 then { structure check }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(super), "\", strip(scapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Batch");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, "Application=.\check.bch");
    filewrite(pfffile, concat("InputData=", strip(raw), "\", hcodes, xcluster,"M", ".DAT"));
    filewrite(pfffile, "Listing=.\check.lst");
    filewrite(pfffile, "");
    filewrite(pfffile, "[ExternalFiles]");
    filewrite(pfffile, "CLUSTER_TRACKING_DICT=.\cluster_tracking.dat");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, "ViewListing=Always");
  elseif mychoice = 4 then { verification }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(super), "\", strip(cmapp), ".cmp.pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Compare");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, "Application=.\compare.cmp");
    filewrite(pfffile, concat("InputData=", strip(raw), "\", hcodes, xcluster,"M", ".DAT"));
    filewrite(pfffile, "Listing=.\compare.cmp.lst");
    filewrite(pfffile, concat("ReferenceData=", strip(floppy), "\", hcodes, xcluster,"V", ".DAT"));
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, "ViewListing=Always");
  elseif mychoice = 7 then { editing }
        noyes = accept("Primera corrida del Programa de Edicin de este Consultorio","No","Si");
        frstrun = edit("9",noyes-1);
    setfile(pfffile,concat(strip(wrkprj), "\", strip(super), "\", strip(edapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Batch");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, "Application=.\editing.bch");
    filewrite(pfffile, concat("InputData=", strip(raw), "\", hcodes, xcluster,"M", ".DAT"));
    filewrite(pfffile, "Listing=.\editing.lst");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, "ViewListing=Always");
    filewrite(pfffile, concat("Parameter=",frstrun));
  elseif mychoice = 8 then { data entry }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(entry), "\", strip(deapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Entry");
    filewrite(pfffile, "");
    filewrite(pfffile, "[DataEntryInit]");
    filewrite(pfffile, concat("OperatorID=", strip(opid)));
    filewrite(pfffile, "Lock=Add, Verify");
    filewrite(pfffile, "Fullscreen=No");
    filewrite(pfffile, "NoFileOpen=Yes");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, concat("Application=", strip(wrkprj), "\", strip(entry), "\", strip(deapp), ".ent"));
    filewrite(pfffile, concat("InputData=", strip(raw), "\", hcodes, xcluster,"M", ".DAT"));
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, concat("Parameter=", xcluster));
  elseif mychoice = 11 then { export to SPSS }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(expdir), "\", strip(exapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Batch");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, "Application=..\export\export.bch");
    filewrite(pfffile, concat("InputData=", strip(final), "\all.dat"));
    filewrite(pfffile, "Listing=..\export\export.lst");
    filewrite(pfffile, "");
    filewrite(pfffile, "[UserFiles]");
    filewrite(pfffile, "MYCH=..\..\SPSS\MYCH.DAT");
    filewrite(pfffile, "MYHH=..\..\SPSS\MYHH.DAT");
    filewrite(pfffile, "MYHL=..\..\SPSS\MYHL.DAT");
    filewrite(pfffile, "MYWM=..\..\SPSS\MYWM.DAT");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, "ViewListing=Always");
  elseif mychoice = 13 or mychoice = 14 then { enter or modify GPS data }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(gps), "\", strip(gpapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Entry");
    filewrite(pfffile, "");
    filewrite(pfffile, "[DataEntryInit]");
    filewrite(pfffile, concat("OperatorID=", strip(opid)));
    if mychoice = 13 then { add data }
      filewrite(pfffile, "Lock=Modify,Verify");
    elseif mychoice = 14 then { modify data }
      filewrite(pfffile, "Lock=Add,Verify");
    endif;
    filewrite(pfffile, "Fullscreen=No");
    filewrite(pfffile, "NoFileOpen=Yes");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, concat("Application=", strip(wrkprj), "\", strip(gps), "\", strip(gpapp), ".ent"));
    filewrite(pfffile, concat("InputData=","..\", strip(gps), "\gps.dat"));
    filewrite(pfffile, "");
  elseif mychoice = 17 then { print cluster tracking info check }
    setfile(pfffile,concat(strip(wrkprj), "\", strip(super), "\", strip(printapp), ".pff"));
    filecreate(pfffile);
    filewrite(pfffile, "[Run Information]");
    filewrite(pfffile, "Version=CSPro 2.6");
    filewrite(pfffile, "AppType=Batch");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Files]");
    filewrite(pfffile, "Application=.\print_tracking_info.bch");
    filewrite(pfffile, concat("InputData=", strip(wrkprj), "\", strip(super), "\", strip(clusterapp), ".DAT"));
    filewrite(pfffile, "Listing=.\print_tracking_info.lst");
    filewrite(pfffile, "");
    filewrite(pfffile, "[Parameters]");
    filewrite(pfffile, "ViewListing=Always");
  endif;

  close(pfffile);
end;

function runpff(mychoice);
  if mychoice = 1 then { cluster info entry }
    Execsystem(concat('"', strip(cspro), '\CSEntry.exe" ',
                      strip(wrkprj), "\", strip(super), "\", strip(clusterapp), '.pff'),
               maximized,wait);
  elseif mychoice = 3 then { structure checking }
    { Using single quotes instad of double quotes as double quotes are needed in the string generated }
    Execsystem(concat('"', strip(cspro), '\CSBatch.exe" ',
                      strip(wrkprj), "\", strip(super), "\", strip(scapp), '.pff'),
               maximized,wait);
  elseif mychoice = 4 then { verification }
    Execsystem(concat('"', strip(cspro), '\CSDiff.exe" ',
                      strip(wrkprj), "\", strip(super), "\", strip(cmapp), '.cmp.pff'),
               maximized,wait);
    t = accept("Verificacin completa?", "1 Si", "2 No");
    if t = 1 then
       tcluster = ecluster;
       t = loadcase(cluster_tracking_dict, tcluster);
       if !t then
         { do nothing  }
         errmsg("Informacion de seguimiento del consultorio no ingresada");
       else
         TVERI = sysdate("DDMMYYYY");
         t = writecase(cluster_tracking_dict, tcluster);
         close(cluster_tracking_dict);
       endif;
    endif;
  elseif mychoice = 7 then { editing }
    if noyes = 1 | noyes = 2 then { if user didn't hit cancel in accept menu }
      Execsystem(concat('"', strip(cspro), '\CSBatch.exe" ',
                        strip(wrkprj), "\", strip(super), "\", strip(edapp), '.pff'),
                 maximized,wait);
          t = accept("Edicin completa?", "1 Si", "2 No");
      if t = 1 then
        tcluster = ecluster;
        t = loadcase(cluster_tracking_dict, tcluster);
        if !t then
          { do nothing }
          errmsg("Informacin del consultorio no ingresada");
        else
          TEDIT = sysdate("DDMMYYYY");
          t = writecase(cluster_tracking_dict, tcluster);
          close(cluster_tracking_dict);
        endif;
      endif;
    endif;

  elseif mychoice = 8 then { data entry }
    Execsystem(concat('"', strip(cspro), '\CSEntry.exe" ',
                      strip(wrkprj), "\", strip(entry), "\", strip(deapp), '.pff'),
               maximized,wait);
  elseif mychoice = 11 then { export to SPSS }
    Execsystem(concat('"', strip(cspro), '\CSBatch.exe" ',
                      strip(wrkprj), "\", strip(expdir), "\", strip(exapp), '.pff'),
               maximized,wait);
  elseif mychoice = 13 or mychoice = 14 then { GPS data entry }
    Execsystem(concat('"', strip(cspro), '\CSEntry.exe" ',
                      strip(wrkprj), "\", strip(gps), "\", strip(gpapp), '.pff'),
               maximized,wait);
  elseif mychoice = 17 then { print cluster tracking info }
    { Using single quotes instad of double quotes as double quotes are needed in the string generated }
    Execsystem(concat('"', strip(cspro), '\CSBatch.exe" ',
                      strip(wrkprj), "\", strip(super), "\", strip(printapp), '.pff'),
               maximized,wait);
  endif;
end;

function csrun(mychoice)
  if chkexist(mychoice) then
    genpff(mychoice);
    runpff(mychoice);
  endif;
end;

function transfer(mychoice)
  if mychoice = 3 or mychoice = 4 then { if checking structure }
    if fileexist(wdata) then
      docopy = accept("Duplica archivo principal de datos?","No","Si")-1;
    else
      docopy = 1;
    endif;
    if docopy = 1 then
      { !!! NETWORK !!! remove message if using a network }
      errmsg("*** Inserte un diskette con datos principales en el drive %s",floppy);
      setfile(mdata,concat(strip(floppy), "\",hcodes, xcluster, "M", ".DAT"));
      if !fileexist(mdata) then { if main data not on diskette }
        { !!! NETWORK !!! change wording of message if using a network }
        errmsg("Archivo principal de datos del consultorio %s no existe en el diskette",xcluster);
        chkok = 0;
      else
        filecopy(mdata,wdata);
        errmsg("El archivo principal de datos del consultorio %s fue copiado al directorio de datos",xcluster);
        if mychoice = 4 then
          chkexist(4);
        endif;
        genpff(mychoice);
        runpff(mychoice);
      endif;
    elseif docopy = 0 then { docopy can equal -1 if user hits cancel }
      if mychoice = 4 then
        chkexist(4);
      endif;
      genpff(mychoice);
      runpff(mychoice);
    endif;
  elseif mychoice = 5 then
    if chkexist(mychoice) then
      { copy the data to the backup directory }
      setfile(datacopy,concat(strip(backup), "\",hcodes,xcluster, "M",  ".dat"));
      filecopy(wdata,datacopy);
      errmsg("El archivo de datos principal del consultorio %s fue copiado al directorio de respaldo",xcluster);

      { Write cluster tracking info }
      tcluster = ecluster;
      t = loadcase(cluster_tracking_dict, tcluster);
      if !t then
        { do nothing   }
        errmsg("La informacin del consultorio no fue ingresada");
      else
        TRAW = sysdate("DDMMYYYY");
        t = writecase(cluster_tracking_dict, tcluster);
        close(cluster_tracking_dict);
      endif;
    endif;
  elseif mychoice = 9 then
    if chkexist(mychoice) then
      { copy the data to the final directory }
      setfile(datacopy,concat(strip(final), "\",hcodes,xcluster, "M",  ".dat"));
      filecopy(wdata,datacopy);
      errmsg("El archivo principal de datos del consultorio %s fue copiado al directorio final",xcluster);
      { Write cluster tracking info }
      tcluster = ecluster;
      t = loadcase(cluster_tracking_dict, tcluster);
      if !t then
        { do nothing }
        errmsg("La informacin del consultorio no fue ingresada");
      else
        TFINAL = sysdate("DDMMYYYY");
        t = writecase(cluster_tracking_dict, tcluster);
        close(cluster_tracking_dict);
      endif;
    endif;
  elseif mychoice = 11 then
    { concatonate the cluster data }
    setfile(alldata,concat(strip(final), "\all.dat"));
    fileconcat(alldata,concat(strip(final),"\",hcodes,"*M.dat"));
    csrun(mychoice);
  endif;
end;

PROC SUPER_FF
preproc
{ The following directories are assumed }
{ \MICS        Main survey directory (some files located here)}
{ \MICS\BACKUP Directory used to store backup data            }
{ \MICS\DICTS  Directory used to store dictionaries           }
{ \MICS\ENTRY  Data entry programs located here               }
{ \MICS\EXPORT Directory used to store export programs        }
{ \MICS\FINAL  Directory used to store final data             }
{ \MICS\GPS    Directory used to store GPS data               }
{ \MICS\RAW    Directory used to store raw data               }

CSPro="C:\Archivos de Programa\CSPro 2.6"; {!!! For spanish versions of windows, this address should be used instead }
{CSPro="C:\Program Files\CSPro 2.6";} { CSPRO directory }
proj="MICS\CSPRO";                                      { Project directory }
cmapp="COMPARE";                                        { Compare application name }
deapp="ENTRY";                                          { Entry application name }
edapp="EDITING";                                        { Editing application name }
exapp="EXPORT";                                         { Export application name }
gpapp="GPSENTRY";                                       { GPS application name }
scapp="CHECK";                                          { Structure check application name }
clusterapp="CLUSTER_TRACKING";          { Cluster info entry application name }
printapp="PRINT_TRACKING_INFO";         { Cluster info printing application name }
dic="MICS3";                                            { Dictionary name }
floppy="C:\MICS3\datos";                                     { !!! NETWORK !!! if using network, change "A:" to shared directory }
fcodes = "MV";                                          { File codes - M = Main, V = Verification,) }
hcodes = "HH";
maxclusternumber = 501;                         { !!! CLUSTER !!! set value of largest cluster number }
wrkdrv="C:";                                    { Set work drive }
wrkprj=concat(strip(wrkdrv), "\", PROJ);

raw=concat(strip(wrkprj), "\RAW");                      { Raw data directory }
backup=concat(strip(wrkprj), "\BACKUP");        { Backup of raw data directory }
final=concat(strip(wrkprj), "\FINAL");          { Backup of final data directory }
dicts="Dicts";                                                          { Dictionary directory }
entry="Entry";                                                          { Entry applications directory }
expdir="Export";                                                        { Export directory }
gps="GPS";                                                                      { GPS directory }
super="Super";                                                          { Supervisor's applications directory }

{ Check that all directories needed exist }
xdir = wrkprj; chkdir();
xdir = concat(strip(wrkprj), "\", strip(dicts)); chkdir();
xdir = concat(strip(wrkprj), "\", strip(entry)); chkdir();
xdir = concat(strip(wrkprj), "\", strip(expdir)); chkdir();
xdir = concat(strip(wrkprj), "\", strip(gps)); chkdir();
xdir = concat(strip(wrkprj), "\", strip(super)); chkdir();
xdir = backup; chkdir();
xdir = final; chkdir();
xdir = raw; chkdir();

{ create the file name variable justone}
setfile(jstone,concat(strip(wrkprj),"\justone.txt"));


{ Check that there are not two concurrent sessions of CSPro loaded at the same time }
if fileexist(jstone) then
  errmsg("Hay otra sesin de entrada de datos corriendo o la aplicacin abort mientras corria");
  if accept("Reanudar","Si","No") = 1 then
    filedelete(jstone)
  else
    stop(-1);
  endif;
endif;

{ create the file justone [it is deleted when option 11, quit, is selected by the DE operator }
setfile(jstone,concat(strip(wrkprj),"\justone.txt"),create);

PROC ECLUSTER
{ !!! CLUSTER !!! give list of valid cluster numbers }
recode ecluster => err;
        001-501 => 0;  { Give list of valid cluster Cuba }
    { 001-032 => 0;    { Give list of valid cluster Pinar }}
	{ 033-064 => 0;    { Give list of valid cluster P Habana }}
    { 065-163 => 0;    { Give list of valid cluster C. Hab }}
    { 164-193 => 0;    { Give list of valid cluster Mat }}
    { 194-230 => 0;    { Give list of valid cluster V. Clara }}
    { 231-248 => 0;    { Give list of valid cluster Cienf }}
    { 249-269 => 0;    { Give list of valid cluster Sancti Spritus }}
    { 270-287 => 0;    { Give list of valid cluster Ciego de Avila }}
    { 288-322 => 0;    { Give list of valid cluster Camagey }}
    { 323-345 => 0;    { Give list of valid cluster Las Tunas }}
    { 346-391 => 0;    { Give list of valid cluster Holgun }}
    { 392-428 => 0;    { Give list of valid cluster Granma }}
    { 429-474 => 0;    { Give list of valid cluster Santiago de Cuba }}
    { 475-497 => 0;    { Give list of valid cluster Guantnamo }}
    { 498-501 => 0;    { Give list of valid cluster Isla de la Juventud }}
                => 1;
endrecode;
if err then
  display("El nmero del consultorio es no es vlido para su provincia");
  reenter;
endif;
{ !!! CLUSTER !!! check length of edit pattern matches length of largest cluster number }
xcluster = edit("999",$);
{ set location of raw data }
setfile(wdata,concat(strip(raw), "\",hcodes, xcluster, "M", ".DAT"));
{ set name of file that helps make sure that only one version of CSPRO runs at a time }
setfile(jstone,concat(strip(wrkprj),"\justone.txt"));
{ set name of the project directory }
setfile(dirname,wrkprj);
close(dirname);

always = 1;
while always do   { loop forever }
  { Get the selected option }
  choice = accept("Opciones del men del Supervisor",
                  "T Ingreso de informacin del consultorio ..........T",
                  "----------------------------------------------------",
                  "A Chequeo de estructura de datos ..................A",
                  "B Verificacin de los datos .......................B",
                  "C Respaldo de datos originales ....................C",
                  "----------------------------------------------------",
                  "D Ejecucin de la edicin secundaria ..............D",
                  "E Modificacin de datos ...........................E",
                  "F Respaldo de los datos finales ...................F",
                  "----------------------------------------------------",
                  "G Exportar datos a SPSS (todos los clusters) ......G",
                  "----------------------------------------------------",
                  "H Ingreso datos del GPS ...........................H",
                  "I Modificacin datos del GPS ......................I",
                  "----------------------------------------------------",
                  "N Nuevo nmero de consultorio .....................N",
                  "V Ver informacin del consultorio .................V",
                  "Q Fin de la sesin ................................Q");

  if choice = 1 then
    tcluster = ecluster;
    t = loadcase(cluster_tracking_dict, tcluster);
        { If we're not able to load the case, initialize data file }
    if !t then
      display("Inicializacin del archivo. Por favor haga click en 'ok' y espere");
      { set whole record to zero }
      TRECV = 0; TNUMHHSEL = 0; TNUMHHCOMP = 0; TNUMHHQUEST = 0;
      TNUMWMQUEST = 0; TNUMWMCOMP = 0; TNUMCHQUEST = 0; TNUMCHCOMP = 0;
      TENTRYOPID = 0; TENTRY = 0; TVENTRYOPID = 0; TVENTRY = 0; TVERI = 0;
      TCHECK = 0; TRAW = 0; TEDIT = 0; TFINAL = 0;
      i = 1;
      { For each cluster }
      open(cluster_tracking_dict);
      while i <= maxclusternumber do
        { !!! CLUSTER !!! check length of edit pattern matches length of largest cluster number }
        recode i       => valid;
               001-501 => 1;     {!!! Give list of valid cluster numbers !!!}
               { 001-032 => 1;    { Give list of valid cluster Pinar }}
	    	 { 033-064 => 1;    { Give list of valid cluster P Habana }}
    		 { 065-163 => 1;    { Give list of valid cluster C. Hab }}
    		 { 164-193 => 1;    { Give list of valid cluster Mat }}
    		 { 194-230 => 1;    { Give list of valid cluster V. Clara }}
    		 { 231-248 => 1;    { Give list of valid cluster Cienf }}
    		 { 249-269 => 1;    { Give list of valid cluster Sancti Spritus }}
    		 { 270-287 => 1;    { Give list of valid cluster Ciego de Avila }}
    		 { 288-322 => 1;    { Give list of valid cluster Camagey }}
    		 { 323-345 => 1;    { Give list of valid cluster Las Tunas }}
    		 { 346-391 => 1;    { Give list of valid cluster Holgun }}
    		 { 392-428 => 1;    { Give list of valid cluster Granma }}
    		 { 429-474 => 1;    { Give list of valid cluster Santiago de Cuba }}
    		 { 475-497 => 1;    { Give list of valid cluster Guantnamo }}
    		 { 498-501 => 1;    { Give list of valid cluster Isla de la Juventud }}
                       => 0;
        endrecode;
        if valid then
          tcluster = i;
          { Write information for this cluster to file }
          t = writecase(cluster_tracking_dict, tcluster);
          if !t then
            errmsg("No fue posible crear el archivo de datos del consultorio");
            break;
          endif;
        endif;
        i = i + 1;
      enddo;
      { reset value of tcluster---which may have changed above---to equal ecluster }
      tcluster = ecluster;
      close(cluster_tracking_dict);
    endif;
    { Check what the user wants to do }
    startpos = accept("Que desea hacer:",
                      "1 Ingresar fechas de recepcin y recuento de consultorios",
                      "2 Ingresar identificacin del digitador",
                      "3 Ingresar identificacin del verificador");
    if startpos > 0 then { If user hits escape or cancel button, return to main menu }
      enter cluster_tracking_ff;
      { make SURE value of tcluster is correct }
      tcluster = ecluster;
      t = writecase(cluster_tracking_dict, tcluster);
      if !t then
        errmsg("No es posible grabar informacin relativa al consultorio %03d");
      endif;
    endif;
    close(cluster_tracking_dict);
  endif;

      if choice =  0 then {ESC} reenter; { escape from menu & allow entry of new cluster number }
  elseif choice =  3 then {A} transfer(choice);   { Structure Check             }
  elseif choice =  4 then {B} transfer(choice);   { Verification                }
  elseif choice =  5 then {C} transfer(choice);   { Backup Raw Data             }
  elseif choice =  6 then {---}                   { do nothing                  }
  elseif choice =  7 then {D} csrun(choice);      { Editing                     }
  elseif choice =  8 then {E} csrun(choice);      { Modify the Data             }
  elseif choice =  9 then {F} transfer(choice);   { Backup Final Data           }
  elseif choice =  10 then {---}                  { do nothing                  }
  elseif choice =  11 then {G} transfer(choice);  { Export to SPSS              }
  elseif choice =  12 then {---}                  { do nothing                  }
  elseif choice =  13 then {H} csrun(choice);     { Enter GPS data              }
  elseif choice =  14 then {I} csrun(choice);     { Modify GPS data             }
  elseif choice =  15 then {---}                  { do nothing                  }
  elseif choice =  16 then {NEW} reenter;         { get the new cluster number  }
  elseif choice =  17 then {NEW} csrun(choice);  { print cluster tracking info  }
  elseif choice =  18 then {QUIT}
    if fileexist(jstone) then
      filedelete(jstone);
    endif;
    stop(-1);       { quit the process }
  endif;
enddo;

PROC TRECVD
preproc
if startpos <> 1 then
    advance TENTRYOPID;
endif;

PROC TRECVY
recode TRECVY  :     TRECVM        : TRECVD => err;
        2006 : 1,3,5,7         : 1-31 => 0;
        2006 : 4,6             : 1-30 => 0;
        2006 : 2               : 1-28 => 0;
             :                 :      => 1;
endrecode;
if err then
  errmsg("Fecha invalida");
  reenter
endif;
dd = (TRECVY*100 + TRECVM)*100 + TRECVD;
ss = sysdate("yyyymmdd");
if dd > ss then
  errmsg("La fecha de recepcin es invalida");
  reenter
endif;
PROC TNUMHHQUEST
if TNUMHHQUEST <> TNUMHHSEL then
        errmsg("Numero de hogares (%02d) no es igual al numero seleccionado (%02d)", TNUMHHQUEST, TNUMHHSEL);
endif;
PROC TNUMHHCOMP
if (TNUMHHQUEST < TNUMHHCOMP) then
    errmsg("Numero de hogares completos (%02d) es mayor que el total de hogares (%02d)", TNUMHHCOMP, TNUMHHQUEST);
    reenter;
endif;
PROC TNUMWMCOMP
if (TNUMWMQUEST < TNUMWMCOMP) then
    errmsg("Numero de hogares completos (%02d) es mayor que el total de mujeres (%02d)", TNUMWMCOMP, TNUMWMQUEST);
    reenter;
endif;
PROC TNUMCHCOMP
if (TNUMCHQUEST < TNUMCHCOMP) then
    errmsg("Numero de hogares completos (%02d) es mayor que el total de nios (%02d)", TNUMCHCOMP, TNUMCHQUEST);
    reenter;
endif;

if startpos = 1 then
    advance;
endif;

PROC TENTRYOPID
preproc
if startpos <> 2 then
    advance TVENTRYOPID;
endif;

PROC TENTRYY
if startpos = 2 then
    { Only check date when we are entering it }
    recode TENTRYY  :     TENTRYM        : TENTRYD => err;
            2006 : 1,3,5,7         : 1-31 => 0;
            2006 : 4,6             : 1-30 => 0;
            2006 : 2               : 1-28 => 0;
                 :                 :      => 1;
    endrecode;
    if err then
      errmsg("Fecha invalida");
      reenter
    endif;
    dd = (TENTRYY*100 + TENTRYM)*100 + TENTRYD;
    dr = (TRECVY*100 + TRECVM)*100 + TRECVD;
    ss = sysdate("yyyymmdd");
    if dd > ss or dd < dr then
      errmsg("La fecha dada es anterior a la fecha de recepcin o posterior a la fecha actual");
      reenter
    endif;
    advance;
endif;
PROC TVENTRYOPID
{ if verification entry has been assigned [TVENTRYOPID <> 0]
  and veri data entry operator equals main data entry operator [TVENTRYOPID = TENTRYOPID]}
if TVENTRYOPID <> 0 and TVENTRYOPID = TENTRYOPID then
    errmsg("La verificacin de los datos no puede ser efectuada por el mismo operador que realiz el ingreso");
    reenter;
endif;
PROC TVENTRYY
if startpos = 3 then
        { Only check date when we are entering it }
        recode TVENTRYY  :     TVENTRYM        : TVENTRYD => err;
           2005-2006 : 1,3,5,7,8,10,12 : 1-31 => 0;
           2005-2006 : 4,6,9,11        : 1-30 => 0;
           2005-2006 : 2               : 1-28 => 0;
                     :                 :      => 1;
        endrecode;
        if err then
          errmsg("Fecha invalida");
          reenter
        endif;
        dd = (TVENTRYY*100 + TVENTRYM)*100 + TVENTRYD;
        dr = (TRECVY*100 + TRECVM)*100 + TRECVD;
        de = (TENTRYY*100 + TENTRYM)*100 + TENTRYD;
        ss = sysdate("yyyymmdd");
        if dd > ss or dd < dr or dd < de then
          errmsg("La fecha dada es anterior a la fecha de recepcin o el ingreso de los datos, o posterior a la fecha actual");
          reenter
        endif;
endif;
